From 2d84c9d3ad0aaea0620658024537d54e6a7939f4 Mon Sep 17 00:00:00 2001 From: Timothy Pearson Date: Sat, 26 Jan 2013 13:17:00 -0600 Subject: [PATCH] Rename a number of libraries and executables to avoid conflicts with KDE4 --- configure.in.in | 6 +- dcopjava/dcopidl2java/Makefile.am | 2 +- dcoppython/test/dcopserver/Makefile.am | 2 +- kalyptus/ChangeLog | 2 +- kalyptus/README | 2 +- kalyptus/kalyptusCxxToJNI.pm | 20 ++--- kalyptus/kalyptusCxxToJava.pm | 18 ++-- kalyptus/kalyptusCxxToKimono.pm | 18 ++-- kalyptus/kalyptusCxxToSmoke.pm | 16 ++-- kalyptus/kalyptusCxxToSwig.pm | 2 +- kalyptus/kalyptusDataDict.pm | 2 +- kdejava/ChangeLog | 4 +- kdejava/TODO | 2 +- kdejava/koala.kdevprj | 2 +- kdejava/koala/Makefile.am | 4 +- kdejava/koala/kdejava/BrowserExtension.cpp | 2 +- .../koala/kdejava/BrowserHostExtension.cpp | 2 +- kdejava/koala/kdejava/BrowserRun.cpp | 4 +- kdejava/koala/kdejava/DockMainWindow.cpp | 4 +- kdejava/koala/kdejava/Element.cpp | 20 ++--- kdejava/koala/kdejava/Element.h | 10 +-- kdejava/koala/kdejava/Event.cpp | 2 +- kdejava/koala/kdejava/Factory.cpp | 2 +- kdejava/koala/kdejava/GUIActivateEvent.cpp | 2 +- kdejava/koala/kdejava/HistoryProvider.cpp | 2 +- kdejava/koala/kdejava/KCombiView.cpp | 2 +- kdejava/koala/kdejava/KDEJavaSlot.h | 8 +- kdejava/koala/kdejava/KDirLister.cpp | 2 +- kdejava/koala/kdejava/KDirOperator.cpp | 2 +- kdejava/koala/kdejava/KDirSize.cpp | 2 +- kdejava/koala/kdejava/KFileDetailView.cpp | 2 +- kdejava/koala/kdejava/KFileIconView.cpp | 2 +- kdejava/koala/kdejava/KFilePreview.cpp | 2 +- kdejava/koala/kdejava/KFileView.cpp | 2 +- kdejava/koala/kdejava/KHTMLPart.cpp | 4 +- kdejava/koala/kdejava/KHTMLSettings.cpp | 2 +- kdejava/koala/kdejava/KHTMLView.cpp | 2 +- kdejava/koala/kdejava/KMdi.cpp | 2 +- kdejava/koala/kdejava/KMdiChildArea.cpp | 2 +- kdejava/koala/kdejava/KMdiChildFrm.cpp | 2 +- kdejava/koala/kdejava/KMdiChildFrmCaption.cpp | 2 +- .../kdejava/KMdiChildFrmDragBeginEvent.cpp | 2 +- .../kdejava/KMdiChildFrmDragEndEvent.cpp | 2 +- .../koala/kdejava/KMdiChildFrmMoveEvent.cpp | 2 +- .../kdejava/KMdiChildFrmResizeBeginEvent.cpp | 2 +- .../kdejava/KMdiChildFrmResizeEndEvent.cpp | 2 +- kdejava/koala/kdejava/KMdiChildView.cpp | 2 +- kdejava/koala/kdejava/KMdiMainFrm.cpp | 4 +- kdejava/koala/kdejava/KMdiTaskBar.cpp | 2 +- kdejava/koala/kdejava/KMdiTaskBarButton.cpp | 2 +- .../koala/kdejava/KMdiToolViewAccessor.cpp | 2 +- kdejava/koala/kdejava/KMdiViewCloseEvent.cpp | 2 +- kdejava/koala/kdejava/KMdiWin32IconButton.cpp | 2 +- kdejava/koala/kdejava/KMultiTabBar.cpp | 2 +- kdejava/koala/kdejava/KMultiTabBarButton.cpp | 2 +- kdejava/koala/kdejava/KMultiTabBarTab.cpp | 2 +- kdejava/koala/kdejava/KMultipleDrag.cpp | 2 +- kdejava/koala/kdejava/KSpell.cpp | 2 +- kdejava/koala/kdejava/KSpellDlg.cpp | 2 +- kdejava/koala/kdejava/KSycoca.cpp | 4 +- kdejava/koala/kdejava/KSycocaEntry.cpp | 4 +- .../koala/kdejava/LiveConnectExtension.cpp | 2 +- kdejava/koala/kdejava/MainWindow.cpp | 4 +- kdejava/koala/kdejava/Makefile.am | 2 +- kdejava/koala/kdejava/MetaInfoJob.cpp | 2 +- kdejava/koala/kdejava/OpenURLEvent.cpp | 2 +- kdejava/koala/kdejava/Part.cpp | 2 +- kdejava/koala/kdejava/PartActivateEvent.cpp | 2 +- kdejava/koala/kdejava/PartBase.cpp | 2 +- kdejava/koala/kdejava/PartManager.cpp | 2 +- kdejava/koala/kdejava/PartSelectEvent.cpp | 2 +- kdejava/koala/kdejava/Plugin.cpp | 2 +- kdejava/koala/kdejava/PreviewJob.cpp | 2 +- kdejava/koala/kdejava/ReadOnlyPart.cpp | 2 +- kdejava/koala/kdejava/ReadWritePart.cpp | 2 +- kdejava/koala/kdejava/StatusBarExtension.cpp | 2 +- kdejava/koala/kdejava/TDEIO.cpp | 4 +- kdejava/koala/kdejava/URLArgs.cpp | 2 +- kdejava/koala/kdejava/WindowArgs.cpp | 2 +- kdejava/koala/org/kde/koala/Element.java | 10 +-- kdejava/koala/org/kde/koala/Factory.java | 2 +- .../koala/org/kde/koala/HistoryProvider.java | 6 +- kdejava/koala/org/kde/koala/KHTMLPart.java | 36 ++++---- .../koala/org/kde/koala/KServiceGroup.java | 2 +- kdejava/koala/org/kde/koala/KSpell.java | 2 +- kdejava/koala/org/kde/koala/KSpellConfig.java | 4 +- .../koala/org/kde/koala/KStringHandler.java | 4 +- kdejava/koala/org/kde/koala/KSycoca.java | 2 +- kdejava/koala/org/kde/koala/KSycocaEntry.java | 2 +- kdejava/koala/org/kde/koala/KTrader.java | 2 +- kdejava/koala/org/kde/koala/Part.java | 2 +- .../test/simplebrowser/KSimpleBrowser.java | 14 +-- kjsembed/Makefile.am | 2 +- kjsembed/builtins/Makefile.am | 2 +- kjsembed/customobject_imp.cpp | 14 +-- kjsembed/customobject_imp.h | 6 +- kjsembed/docs/ChangeLog | 2 +- .../docs/embedding/simple-embed/Makefile.am | 2 +- kjsembed/docs/embedding/simple-embed/README | 2 +- kjsembed/jsfactory.cpp | 6 +- kjsembed/kjsembedpart.h | 2 +- kjsembed/plugin/jsconsoleplugin.cpp | 2 +- kjsembed/plugin/jsconsoleplugin.h | 2 +- kjsembed/{kscript => tdescript}/Makefile.am | 2 +- .../{kscript => tdescript}/javascript.cpp | 0 .../{kscript => tdescript}/javascript.desktop | 0 kjsembed/{kscript => tdescript}/javascript.h | 0 .../{kscript => tdescript}/swaptabs.desktop | 0 kjsembed/{kscript => tdescript}/swaptabs.js | 0 kjsembed/{kscript => tdescript}/swaptabs.ui | 0 ...t_kparts_args.js => test_tdeparts_args.js} | 0 korundum/bin/Makefile.am | 2 +- korundum/rubylib/examples/RubberDoc.rb | 26 +++--- .../examples/{uikmdi.rb => uitdemdi.rb} | 6 +- .../examples/{uikmdi.rc => uitdemdi.rc} | 0 korundum/rubylib/korundum/Korundum.cpp | 6 +- korundum/rubylib/korundum/kdehandlers.cpp | 6 +- .../rubylib/rbkconfig_compiler/Makefile.am | 2 +- qtruby/ChangeLog | 4 +- qtruby/rubylib/qtruby/Qt.cpp | 20 ++--- smoke/kde/generate.pl.in | 6 +- smoke/kde/kde_header_list | 80 +++++++++--------- xparts/doc/{kparts.fig => tdeparts.fig} | 0 xparts/doc/{kparts.png => tdeparts.png} | Bin xparts/doc/xparts.html | 2 +- xparts/mozilla/Makefile.am | 2 +- xparts/mozilla/kmozilla.rc | 2 +- xparts/mozilla/kmozillapart.cpp | 4 +- xparts/mozilla/kshell.cpp | 4 +- xparts/src/gtk/Makefile.am | 2 +- xparts/src/interfaces/Makefile.am | 4 +- xparts/src/interfaces/xpart.h | 4 +- xparts/src/interfaces/xparthost.h | 4 +- xparts/src/interfaces/xpartmanager.h | 4 +- xparts/src/kde/kbrowsersignals.h | 2 +- xparts/src/kde/xparthost_kpart.h | 2 +- xparts/xpart_notepad/shell_xparthost.cpp | 2 +- xparts/xpart_notepad/shell_xparthost.h | 2 +- xparts/xpart_notepad/xp_notepad_factory.cpp | 2 +- xparts/xpart_notepad/xp_notepad_factory.h | 2 +- 140 files changed, 306 insertions(+), 306 deletions(-) rename kjsembed/{kscript => tdescript}/Makefile.am (90%) rename kjsembed/{kscript => tdescript}/javascript.cpp (100%) rename kjsembed/{kscript => tdescript}/javascript.desktop (100%) rename kjsembed/{kscript => tdescript}/javascript.h (100%) rename kjsembed/{kscript => tdescript}/swaptabs.desktop (100%) rename kjsembed/{kscript => tdescript}/swaptabs.js (100%) rename kjsembed/{kscript => tdescript}/swaptabs.ui (100%) rename kjsembed/tests/{test_kparts_args.js => test_tdeparts_args.js} (100%) rename korundum/rubylib/examples/{uikmdi.rb => uitdemdi.rb} (97%) rename korundum/rubylib/examples/{uikmdi.rc => uitdemdi.rc} (100%) rename xparts/doc/{kparts.fig => tdeparts.fig} (100%) rename xparts/doc/{kparts.png => tdeparts.png} (100%) diff --git a/configure.in.in b/configure.in.in index 21f399df..4864ff06 100644 --- a/configure.in.in +++ b/configure.in.in @@ -226,7 +226,7 @@ dnl ********** AC_DEFUN([KDE_CHECK_MDI], [ - AC_MSG_CHECKING(whether to use kmdi lib from tdelibs) + AC_MSG_CHECKING(whether to use tdemdi lib from tdelibs) AC_CACHE_VAL(ac_cv_mdi_setup, [ AC_LANG_SAVE @@ -250,7 +250,7 @@ AC_DEFUN([KDE_CHECK_MDI], ]) if test "$ac_cv_mdi_setup" = "yes"; then - LIB_KMDI="-lkmdi" + LIB_KMDI="-ltdemdi" AC_MSG_RESULT(yes) else LIB_KMDI='' @@ -260,7 +260,7 @@ AC_DEFUN([KDE_CHECK_MDI], AC_SUBST(LIB_KMDI) ]) -dnl Check if kmdi is present, if not don't bother.. +dnl Check if tdemdi is present, if not don't bother.. KDE_CHECK_MDI diff --git a/dcopjava/dcopidl2java/Makefile.am b/dcopjava/dcopidl2java/Makefile.am index 494e5b73..a99e7b6a 100644 --- a/dcopjava/dcopidl2java/Makefile.am +++ b/dcopjava/dcopidl2java/Makefile.am @@ -7,5 +7,5 @@ dcopidl2java_SOURCES = main.cpp skel.cpp stubimpl.cpp noinst_HEADERS = main.h dcopidl2java_LDADD = $(LIB_QT) -dcopidl2java_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -lktexteditor +dcopidl2java_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor diff --git a/dcoppython/test/dcopserver/Makefile.am b/dcoppython/test/dcopserver/Makefile.am index df3acb86..79ee4f8d 100644 --- a/dcoppython/test/dcopserver/Makefile.am +++ b/dcoppython/test/dcopserver/Makefile.am @@ -21,7 +21,7 @@ bin_PROGRAMS = kdedcoptest # the application source, library search path, and link libraries kdedcoptest_SOURCES = main.cpp kdedcoptest.cpp kdedcoptest_iface.skel mainclass.cpp -kdedcoptest_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -lktexteditor +kdedcoptest_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor kdedcoptest_LDADD = $(LIB_TDEUI) # this is where the desktop file will go diff --git a/kalyptus/ChangeLog b/kalyptus/ChangeLog index 15fe6676..be1c44e6 100644 --- a/kalyptus/ChangeLog +++ b/kalyptus/ChangeLog @@ -273,7 +273,7 @@ * Fixed parsing default argument values cast to a numeric literal, eg: mode_t mode = (mode_t)-1 - * Excluded a couple of structs from kparts/browserextension + * Excluded a couple of structs from tdeparts/browserextension 2003-11-04 Richard Dale diff --git a/kalyptus/README b/kalyptus/README index e56448e4..ee3d36c9 100644 --- a/kalyptus/README +++ b/kalyptus/README @@ -52,7 +52,7 @@ KDE headers # Generate Java and C++ sources. Copy all the target headers to directory 'test/tmp' kalyptus -fjava test/tmp/*.h test/tmp/dom/*.h test/tmp/kio/*.h test/tmp/tdeprint/*.h \ - test/tmp/kjs/*.h test/tmp/kparts/*.h test/tmp/tdesu/*.h test/ktextedit/*.h test/tmp/libkmid/*.h + test/tmp/kjs/*.h test/tmp/tdeparts/*.h test/tmp/tdesu/*.h test/ktextedit/*.h test/tmp/libtdemid/*.h # Shorten generated filenames mv DOM__Node.cpp DOMNode.cpp diff --git a/kalyptus/kalyptusCxxToJNI.pm b/kalyptus/kalyptusCxxToJNI.pm index 3b318f94..ec89863e 100644 --- a/kalyptus/kalyptusCxxToJNI.pm +++ b/kalyptus/kalyptusCxxToJNI.pm @@ -2449,12 +2449,12 @@ sub preParseClass $className eq 'TDEIO::MetaData' || $className eq 'KFileMimeTypeInfo::ItemInfo' || $className eq 'TDEIO::UDSAtom' || - $className eq 'khtml::DrawContentsEvent' || # the khtml:: classes build, but don't link - $className eq 'khtml::MouseDoubleClickEvent' || - $className eq 'khtml::MouseMoveEvent' || - $className eq 'khtml::MousePressEvent' || - $className eq 'khtml::MouseReleaseEvent' || - $className eq 'khtml::MouseEvent' || + $className eq 'tdehtml::DrawContentsEvent' || # the tdehtml:: classes build, but don't link + $className eq 'tdehtml::MouseDoubleClickEvent' || + $className eq 'tdehtml::MouseMoveEvent' || + $className eq 'tdehtml::MousePressEvent' || + $className eq 'tdehtml::MouseReleaseEvent' || + $className eq 'tdehtml::MouseEvent' || $className eq 'KURL::List' || $className eq 'KWin::Info' || $className eq 'TerminalInterface' || @@ -3355,7 +3355,7 @@ sub addIncludeForClass($$$) { my ( $node, $addInclude, $debugMe ) = @_; my $sourcename = $node->{Source}->{astNodeName}; - if ( $sourcename !~ s!.*(kio/|kparts/|dom/|kabc/|ksettings/|kjs/|ktexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { + if ( $sourcename !~ s!.*(kio/|tdeparts/|dom/|kabc/|ksettings/|kjs/|tdetexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { $sourcename =~ s!.*/(.*)!$1!m; } # die "Empty source name for $node->{astNodeName}" if ( $sourcename eq '' ); @@ -3624,7 +3624,7 @@ sub generateMethod($$$$$$$$$) return; } - if ( $sourcename !~ s!.*(kio/|kparts/|dom/|kabc/|ksettings/|kjs/|ktexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { + if ( $sourcename !~ s!.*(kio/|tdeparts/|dom/|kabc/|ksettings/|kjs/|tdetexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { $sourcename =~ s!.*/(.*)!$1!m; } if ( $sourcename eq '' ) { @@ -4155,7 +4155,7 @@ sub generateAllMethods($$$$$$$$) my $sourcename = $classNode->{Source}->{astNodeName}; - if ( $sourcename !~ s!.*(kio/|kparts/|dom/|kabc/|ksettings/|kjs/|ktexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { + if ( $sourcename !~ s!.*(kio/|tdeparts/|dom/|kabc/|ksettings/|kjs/|tdetexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { $sourcename =~ s!.*/(.*)!$1!m; } # die "Empty source name for $classNode->{astNodeName} $classNode->{Source}->{astNodeName}" if ( $sourcename eq '' ); @@ -4164,7 +4164,7 @@ sub generateAllMethods($$$$$$$$) $addInclude->{$sourcename} = 1; # my $s; # for my $sn( @{$classNode->{Sources}} ) { -# if ( ($s = $sn->{astNodeName}) !~ s!.*(kio/|kparts/|dom/|kabc/|ksettings/|kjs/|ktexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { +# if ( ($s = $sn->{astNodeName}) !~ s!.*(kio/|tdeparts/|dom/|kabc/|ksettings/|kjs/|tdetexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { # $s =~ s!.*/(.*)!$1!m; # } # $addInclude->{$s} = 1; diff --git a/kalyptus/kalyptusCxxToJava.pm b/kalyptus/kalyptusCxxToJava.pm index d1aa7c3f..2bc86651 100644 --- a/kalyptus/kalyptusCxxToJava.pm +++ b/kalyptus/kalyptusCxxToJava.pm @@ -756,12 +756,12 @@ sub preParseClass $className eq 'TDEIO::MetaData' || $className eq 'KFileMimeTypeInfo::ItemInfo' || $className eq 'TDEIO::UDSAtom' || - $className eq 'khtml::DrawContentsEvent' || # the khtml:: classes build, but don't link - $className eq 'khtml::MouseDoubleClickEvent' || - $className eq 'khtml::MouseMoveEvent' || - $className eq 'khtml::MousePressEvent' || - $className eq 'khtml::MouseReleaseEvent' || - $className eq 'khtml::MouseEvent' || + $className eq 'tdehtml::DrawContentsEvent' || # the tdehtml:: classes build, but don't link + $className eq 'tdehtml::MouseDoubleClickEvent' || + $className eq 'tdehtml::MouseMoveEvent' || + $className eq 'tdehtml::MousePressEvent' || + $className eq 'tdehtml::MouseReleaseEvent' || + $className eq 'tdehtml::MouseEvent' || $className eq 'KURL::List' || $className eq 'KWin::Info' || $className eq 'TerminalInterface' || @@ -1732,7 +1732,7 @@ sub generateMethod($$$$$$$) return; } - if ( $sourcename !~ s!.*(kio/|kparts/|dom/|kabc/|ksettings/|kjs/|ktexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { + if ( $sourcename !~ s!.*(kio/|tdeparts/|dom/|kabc/|ksettings/|kjs/|tdetexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { $sourcename =~ s!.*/(.*)!$1!m; } if ( $sourcename eq '' ) { @@ -2124,7 +2124,7 @@ sub generateAllMethods($$$$$$) my $sourcename = $classNode->{Source}->{astNodeName}; - if ( $sourcename !~ s!.*(kio/|kparts/|dom/|kabc/|ksettings/|kjs/|ktexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { + if ( $sourcename !~ s!.*(kio/|tdeparts/|dom/|kabc/|ksettings/|kjs/|tdetexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { $sourcename =~ s!.*/(.*)!$1!m; } die "Empty source name for $classNode->{astNodeName}" if ( $sourcename eq '' ); @@ -2148,7 +2148,7 @@ sub generateAllMethods($$$$$$) if ($classNode->{astNodeName} ne $main::globalSpaceClassName) { # my $s; # for my $sn( @{$classNode->{Sources}} ) { -# if ( ($s = $sn->{astNodeName}) !~ s!.*(kio/|kparts/|dom/|kabc/|ksettings/|kjs/|ktexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { +# if ( ($s = $sn->{astNodeName}) !~ s!.*(kio/|tdeparts/|dom/|kabc/|ksettings/|kjs/|tdetexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { # $s =~ s!.*/(.*)!$1!m; # } # $addInclude->{$s} = 1; diff --git a/kalyptus/kalyptusCxxToKimono.pm b/kalyptus/kalyptusCxxToKimono.pm index 07a1ace7..710a5219 100644 --- a/kalyptus/kalyptusCxxToKimono.pm +++ b/kalyptus/kalyptusCxxToKimono.pm @@ -776,12 +776,12 @@ sub preParseClass $className eq 'TDEIO::MetaData' || $className eq 'KFileMimeTypeInfo::ItemInfo' || $className eq 'TDEIO::UDSAtom' || - $className eq 'khtml::DrawContentsEvent' || # the khtml:: classes build, but don't link - $className eq 'khtml::MouseDoubleClickEvent' || - $className eq 'khtml::MouseMoveEvent' || - $className eq 'khtml::MousePressEvent' || - $className eq 'khtml::MouseReleaseEvent' || - $className eq 'khtml::MouseEvent' || + $className eq 'tdehtml::DrawContentsEvent' || # the tdehtml:: classes build, but don't link + $className eq 'tdehtml::MouseDoubleClickEvent' || + $className eq 'tdehtml::MouseMoveEvent' || + $className eq 'tdehtml::MousePressEvent' || + $className eq 'tdehtml::MouseReleaseEvent' || + $className eq 'tdehtml::MouseEvent' || $className eq 'KURL::List' || $className eq 'KWin::Info' || $className eq 'TerminalInterface' || @@ -1777,7 +1777,7 @@ sub generateMethod($$$$$$$) return; } - if ( $sourcename !~ s!.*(kio/|kparts/|dom/|kabc/|ksettings/|kjs/|ktexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { + if ( $sourcename !~ s!.*(kio/|tdeparts/|dom/|kabc/|ksettings/|kjs/|tdetexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { $sourcename =~ s!.*/(.*)!$1!m; } if ( $sourcename eq '' ) { @@ -2317,7 +2317,7 @@ sub generateAllMethods($$$$$$) my $sourcename = $classNode->{Source}->{astNodeName}; - if ( $sourcename !~ s!.*(kio/|kparts/|dom/|kabc/|ksettings/|kjs/|ktexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { + if ( $sourcename !~ s!.*(kio/|tdeparts/|dom/|kabc/|ksettings/|kjs/|tdetexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { $sourcename =~ s!.*/(.*)!$1!m; } die "Empty source name for $classNode->{astNodeName}" if ( $sourcename eq '' ); @@ -2339,7 +2339,7 @@ sub generateAllMethods($$$$$$) if ($classNode->{astNodeName} ne $main::globalSpaceClassName) { # my $s; # for my $sn( @{$classNode->{Sources}} ) { -# if ( ($s = $sn->{astNodeName}) !~ s!.*(kio/|kparts/|dom/|kabc/|ksettings/|kjs/|ktexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { +# if ( ($s = $sn->{astNodeName}) !~ s!.*(kio/|tdeparts/|dom/|kabc/|ksettings/|kjs/|tdetexteditor/|tdeprint/|tdesu/)(.*)!$1$2!m ) { # $s =~ s!.*/(.*)!$1!m; # } # $addInclude->{$s} = 1; diff --git a/kalyptus/kalyptusCxxToSmoke.pm b/kalyptus/kalyptusCxxToSmoke.pm index fbfc1b9f..42d9f222 100644 --- a/kalyptus/kalyptusCxxToSmoke.pm +++ b/kalyptus/kalyptusCxxToSmoke.pm @@ -230,7 +230,7 @@ BEGIN 'TQStyle::SubControls' => 'int', ); -$headerSubdirectories = "kio/|tdevelop/|kinterfacedesigner/|kontact/|kate/|kparts/|dom/|kabc/|ksettings/|kjs/|ktexteditor/|tdeprint/|tdesu/|knewstuff/" +$headerSubdirectories = "kio/|tdevelop/|kinterfacedesigner/|kontact/|kate/|tdeparts/|dom/|kabc/|ksettings/|kjs/|tdetexteditor/|tdeprint/|tdesu/|knewstuff/" } @@ -406,13 +406,13 @@ sub preParseClass $className eq 'KPropertiesDialog' || $className eq 'ProgressItem' || $className eq 'TDEIO::ChmodInfo' || - $className eq 'khtml::DrawContentsEvent' || # the khtml:: classes build, but don't link - $className eq 'khtml::MouseDoubleClickEvent' || - $className eq 'khtml::MouseMoveEvent' || - $className eq 'khtml::MousePressEvent' || - $className eq 'khtml::MouseReleaseEvent' || - $className eq 'khtml::MouseEvent' || - $className eq 'khtml' || + $className eq 'tdehtml::DrawContentsEvent' || # the tdehtml:: classes build, but don't link + $className eq 'tdehtml::MouseDoubleClickEvent' || + $className eq 'tdehtml::MouseMoveEvent' || + $className eq 'tdehtml::MousePressEvent' || + $className eq 'tdehtml::MouseReleaseEvent' || + $className eq 'tdehtml::MouseEvent' || + $className eq 'tdehtml' || $className eq 'KURL::List' || $className eq 'KWin::Info' || $className eq 'TerminalInterface' || diff --git a/kalyptus/kalyptusCxxToSwig.pm b/kalyptus/kalyptusCxxToSwig.pm index 555cf30f..8cd2bc12 100644 --- a/kalyptus/kalyptusCxxToSwig.pm +++ b/kalyptus/kalyptusCxxToSwig.pm @@ -838,7 +838,7 @@ sub writeClassDoc my $sourcename = $node->{Source}->{astNodeName}; - if ( $sourcename =~ m!.*(dom|kabc|tdeprint|tdesu|kio|kjs|kparts|ktexteditor|libkmid)/([^/]*$)! ) { + if ( $sourcename =~ m!.*(dom|kabc|tdeprint|tdesu|kio|kjs|tdeparts|tdetexteditor|libtdemid)/([^/]*$)! ) { $sourcename = $1."/".$2; } else { $sourcename =~ s!.*/([^/]*$)!$1!; diff --git a/kalyptus/kalyptusDataDict.pm b/kalyptus/kalyptusDataDict.pm index ed8b1f5d..023c1203 100644 --- a/kalyptus/kalyptusDataDict.pm +++ b/kalyptus/kalyptusDataDict.pm @@ -2862,7 +2862,7 @@ sub addNamespace if ( $className =~ /^(DrawContentsEvent|MouseDoubleClickEvent|MouseEvent|MouseMoveEvent|MousePressEvent|MouseReleaseEvent)/ ) { - return "khtml::".$className; + return "tdehtml::".$className; } if ( $className =~ /^(OfferList)/ ) diff --git a/kdejava/ChangeLog b/kdejava/ChangeLog index a46c28c9..ce043d5b 100644 --- a/kdejava/ChangeLog +++ b/kdejava/ChangeLog @@ -67,7 +67,7 @@ 2003-12-30 Richard Dale * Fixed/removed some compiler warnings from the generated code - * Removed -lkjs, -lkscipt and -lkmid libs from the link options + * Removed -lkjs, -lkscipt and -ltdemid libs from the link options * Removed KDockWindow, KLineEditDlg, KPrinter, KNamedCommand, TDESocket and KRegExpr classes * Added KInputDialog, KExtendedSocket, TDEBufferedIO, KAsyncIO, KDirLister, RenameDlg, @@ -217,7 +217,7 @@ 2002-02-02 Dirk Mueller * koala/kdejava/Makefile.am: removed KKeyChooser as it doesn't compile anymore with current tdelibs. - * Remove private method bindings from khtml/MouseEvent + * Remove private method bindings from tdehtml/MouseEvent * Removed KAccelAction (private header) 2002-02-01 Richard Dale * Removed KToolBarButtonList class diff --git a/kdejava/TODO b/kdejava/TODO index 7e9a34ce..28297865 100644 --- a/kdejava/TODO +++ b/kdejava/TODO @@ -1,4 +1,4 @@ -- Split up and group java classes into sub packages such as 'org.kde.koala.kparts', +- Split up and group java classes into sub packages such as 'org.kde.koala.tdeparts', and 'org.kde.koala.tdecore'. - Split up shared libs into smaller sub-libraries for faster loading, or write diff --git a/kdejava/koala.kdevprj b/kdejava/koala.kdevprj index 4850e002..7090674c 100644 --- a/kdejava/koala.kdevprj +++ b/kdejava/koala.kdevprj @@ -20,7 +20,7 @@ type=DATA addcxxflags= bin_program=koala cxxflags=\s-O0 -Wall -ldadd=$(LIB_KSPELL) -lqtjava -lkparts $(LIB_KIO) -lXext -lX11 +ldadd=$(LIB_KSPELL) -lqtjava -ltdeparts $(LIB_KIO) -lXext -lX11 ldflags= [General] diff --git a/kdejava/koala/Makefile.am b/kdejava/koala/Makefile.am index 907dace1..b7ad22fd 100644 --- a/kdejava/koala/Makefile.am +++ b/kdejava/koala/Makefile.am @@ -4,7 +4,7 @@ noinst_PROGRAMS = koala ## INCLUDES were found outside tdevelop specific part koala_SOURCES = main.cpp -koala_LDADD = ./kdejava/libkdejava.la ../../qtjava/javalib/qtjava/libqtjava.la $(LIB_KSPELL) -lkparts $(LIB_KIO) -lXext -lX11 $(LIBSOCKET) +koala_LDADD = ./kdejava/libkdejava.la ../../qtjava/javalib/qtjava/libqtjava.la $(LIB_KSPELL) -ltdeparts $(LIB_KIO) -lXext -lX11 $(LIBSOCKET) SUBDIRS = org kdejava @@ -36,7 +36,7 @@ INCLUDES= $(all_includes) koala_METASOURCES = AUTO # the library search path. -koala_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -lktexteditor +koala_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor # them while "make clean", use CLEANFILES CLEANFILES = koala.jar diff --git a/kdejava/koala/kdejava/BrowserExtension.cpp b/kdejava/koala/kdejava/BrowserExtension.cpp index a98764ca..5be10ce9 100644 --- a/kdejava/koala/kdejava/BrowserExtension.cpp +++ b/kdejava/koala/kdejava/BrowserExtension.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/BrowserHostExtension.cpp b/kdejava/koala/kdejava/BrowserHostExtension.cpp index 726f87fd..7391bd68 100644 --- a/kdejava/koala/kdejava/BrowserHostExtension.cpp +++ b/kdejava/koala/kdejava/BrowserHostExtension.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/BrowserRun.cpp b/kdejava/koala/kdejava/BrowserRun.cpp index cdc5952a..01501670 100644 --- a/kdejava/koala/kdejava/BrowserRun.cpp +++ b/kdejava/koala/kdejava/BrowserRun.cpp @@ -1,7 +1,7 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include -#include +#include +#include #include #include diff --git a/kdejava/koala/kdejava/DockMainWindow.cpp b/kdejava/koala/kdejava/DockMainWindow.cpp index a142fe0a..8cd0c023 100644 --- a/kdejava/koala/kdejava/DockMainWindow.cpp +++ b/kdejava/koala/kdejava/DockMainWindow.cpp @@ -1,7 +1,7 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include -#include +#include +#include #include #include diff --git a/kdejava/koala/kdejava/Element.cpp b/kdejava/koala/kdejava/Element.cpp index 91c34285..d54c7e0a 100644 --- a/kdejava/koala/kdejava/Element.cpp +++ b/kdejava/koala/kdejava/Element.cpp @@ -110,47 +110,47 @@ Java_org_kde_koala_Element_isHTMLElement(JNIEnv* env, jobject obj) } JNIEXPORT jboolean JNICALL -Java_org_kde_koala_Element_khtmlMalformedPrefix(JNIEnv* env, jclass cls, jstring name) +Java_org_kde_koala_Element_tdehtmlMalformedPrefix(JNIEnv* env, jclass cls, jstring name) { (void) cls; static DOM::DOMString* _domstring_name = 0; - jboolean xret = (jboolean) ElementJBridge::khtmlMalformedPrefix((DOM::DOMString)*(DOM::DOMString*) KDESupport::toDOMString(env, name, &_domstring_name)); + jboolean xret = (jboolean) ElementJBridge::tdehtmlMalformedPrefix((DOM::DOMString)*(DOM::DOMString*) KDESupport::toDOMString(env, name, &_domstring_name)); return xret; } JNIEXPORT jboolean JNICALL -Java_org_kde_koala_Element_khtmlMalformedQualifiedName(JNIEnv* env, jclass cls, jstring name) +Java_org_kde_koala_Element_tdehtmlMalformedQualifiedName(JNIEnv* env, jclass cls, jstring name) { (void) cls; static DOM::DOMString* _domstring_name = 0; - jboolean xret = (jboolean) ElementJBridge::khtmlMalformedQualifiedName((DOM::DOMString)*(DOM::DOMString*) KDESupport::toDOMString(env, name, &_domstring_name)); + jboolean xret = (jboolean) ElementJBridge::tdehtmlMalformedQualifiedName((DOM::DOMString)*(DOM::DOMString*) KDESupport::toDOMString(env, name, &_domstring_name)); return xret; } JNIEXPORT jboolean JNICALL -Java_org_kde_koala_Element_khtmlValidAttrName(JNIEnv* env, jclass cls, jstring name) +Java_org_kde_koala_Element_tdehtmlValidAttrName(JNIEnv* env, jclass cls, jstring name) { (void) cls; static DOM::DOMString* _domstring_name = 0; - jboolean xret = (jboolean) ElementJBridge::khtmlValidAttrName((DOM::DOMString)*(DOM::DOMString*) KDESupport::toDOMString(env, name, &_domstring_name)); + jboolean xret = (jboolean) ElementJBridge::tdehtmlValidAttrName((DOM::DOMString)*(DOM::DOMString*) KDESupport::toDOMString(env, name, &_domstring_name)); return xret; } JNIEXPORT jboolean JNICALL -Java_org_kde_koala_Element_khtmlValidPrefix(JNIEnv* env, jclass cls, jstring name) +Java_org_kde_koala_Element_tdehtmlValidPrefix(JNIEnv* env, jclass cls, jstring name) { (void) cls; static DOM::DOMString* _domstring_name = 0; - jboolean xret = (jboolean) ElementJBridge::khtmlValidPrefix((DOM::DOMString)*(DOM::DOMString*) KDESupport::toDOMString(env, name, &_domstring_name)); + jboolean xret = (jboolean) ElementJBridge::tdehtmlValidPrefix((DOM::DOMString)*(DOM::DOMString*) KDESupport::toDOMString(env, name, &_domstring_name)); return xret; } JNIEXPORT jboolean JNICALL -Java_org_kde_koala_Element_khtmlValidQualifiedName(JNIEnv* env, jclass cls, jstring name) +Java_org_kde_koala_Element_tdehtmlValidQualifiedName(JNIEnv* env, jclass cls, jstring name) { (void) cls; static DOM::DOMString* _domstring_name = 0; - jboolean xret = (jboolean) ElementJBridge::khtmlValidQualifiedName((DOM::DOMString)*(DOM::DOMString*) KDESupport::toDOMString(env, name, &_domstring_name)); + jboolean xret = (jboolean) ElementJBridge::tdehtmlValidQualifiedName((DOM::DOMString)*(DOM::DOMString*) KDESupport::toDOMString(env, name, &_domstring_name)); return xret; } diff --git a/kdejava/koala/kdejava/Element.h b/kdejava/koala/kdejava/Element.h index 047520c4..cdd5e4be 100644 --- a/kdejava/koala/kdejava/Element.h +++ b/kdejava/koala/kdejava/Element.h @@ -34,11 +34,11 @@ extern JNIEXPORT jboolean JNICALL Java_org_kde_koala_Element_contentEditable (JN extern JNIEXPORT void JNICALL Java_org_kde_koala_Element_setContentEditable (JNIEnv *env, jobject, jboolean); extern JNIEXPORT jboolean JNICALL Java_org_kde_koala_Element_isHTMLElement (JNIEnv *env, jobject); extern JNIEXPORT jobject JNICALL Java_org_kde_koala_Element_form (JNIEnv *env, jobject); -extern JNIEXPORT jboolean JNICALL Java_org_kde_koala_Element_khtmlValidAttrName (JNIEnv *env, jclass, jstring); -extern JNIEXPORT jboolean JNICALL Java_org_kde_koala_Element_khtmlValidPrefix (JNIEnv *env, jclass, jstring); -extern JNIEXPORT jboolean JNICALL Java_org_kde_koala_Element_khtmlValidQualifiedName (JNIEnv *env, jclass, jstring); -extern JNIEXPORT jboolean JNICALL Java_org_kde_koala_Element_khtmlMalformedQualifiedName (JNIEnv *env, jclass, jstring); -extern JNIEXPORT jboolean JNICALL Java_org_kde_koala_Element_khtmlMalformedPrefix (JNIEnv *env, jclass, jstring); +extern JNIEXPORT jboolean JNICALL Java_org_kde_koala_Element_tdehtmlValidAttrName (JNIEnv *env, jclass, jstring); +extern JNIEXPORT jboolean JNICALL Java_org_kde_koala_Element_tdehtmlValidPrefix (JNIEnv *env, jclass, jstring); +extern JNIEXPORT jboolean JNICALL Java_org_kde_koala_Element_tdehtmlValidQualifiedName (JNIEnv *env, jclass, jstring); +extern JNIEXPORT jboolean JNICALL Java_org_kde_koala_Element_tdehtmlMalformedQualifiedName (JNIEnv *env, jclass, jstring); +extern JNIEXPORT jboolean JNICALL Java_org_kde_koala_Element_tdehtmlMalformedPrefix (JNIEnv *env, jclass, jstring); #ifdef __cplusplus } diff --git a/kdejava/koala/kdejava/Event.cpp b/kdejava/koala/kdejava/Event.cpp index 2c3820f3..7305e287 100644 --- a/kdejava/koala/kdejava/Event.cpp +++ b/kdejava/koala/kdejava/Event.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/Factory.cpp b/kdejava/koala/kdejava/Factory.cpp index 94fbd1f5..44a75ad0 100644 --- a/kdejava/koala/kdejava/Factory.cpp +++ b/kdejava/koala/kdejava/Factory.cpp @@ -1,6 +1,6 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/GUIActivateEvent.cpp b/kdejava/koala/kdejava/GUIActivateEvent.cpp index 8b0fc956..2fc9ef6b 100644 --- a/kdejava/koala/kdejava/GUIActivateEvent.cpp +++ b/kdejava/koala/kdejava/GUIActivateEvent.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/HistoryProvider.cpp b/kdejava/koala/kdejava/HistoryProvider.cpp index 566e3bc1..68c491c5 100644 --- a/kdejava/koala/kdejava/HistoryProvider.cpp +++ b/kdejava/koala/kdejava/HistoryProvider.cpp @@ -1,6 +1,6 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KCombiView.cpp b/kdejava/koala/kdejava/KCombiView.cpp index 11dfb845..0613d6f4 100644 --- a/kdejava/koala/kdejava/KCombiView.cpp +++ b/kdejava/koala/kdejava/KCombiView.cpp @@ -4,7 +4,7 @@ #include #include #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KDEJavaSlot.h b/kdejava/koala/kdejava/KDEJavaSlot.h index 90c63db0..f1644724 100644 --- a/kdejava/koala/kdejava/KDEJavaSlot.h +++ b/kdejava/koala/kdejava/KDEJavaSlot.h @@ -24,7 +24,7 @@ #include #include -#include +#include #include #include #include @@ -36,14 +36,14 @@ #include #include #include -#include -#include +#include +#include #include #include #include #include #include -#include +#include class KDEJavaSlotFactory; diff --git a/kdejava/koala/kdejava/KDirLister.cpp b/kdejava/koala/kdejava/KDirLister.cpp index c84c0452..ddf550ca 100644 --- a/kdejava/koala/kdejava/KDirLister.cpp +++ b/kdejava/koala/kdejava/KDirLister.cpp @@ -1,6 +1,6 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/KDirOperator.cpp b/kdejava/koala/kdejava/KDirOperator.cpp index ab05c563..94036ad3 100644 --- a/kdejava/koala/kdejava/KDirOperator.cpp +++ b/kdejava/koala/kdejava/KDirOperator.cpp @@ -1,7 +1,7 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include #include -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/KDirSize.cpp b/kdejava/koala/kdejava/KDirSize.cpp index 045d5b22..fbf1027d 100644 --- a/kdejava/koala/kdejava/KDirSize.cpp +++ b/kdejava/koala/kdejava/KDirSize.cpp @@ -1,6 +1,6 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KFileDetailView.cpp b/kdejava/koala/kdejava/KFileDetailView.cpp index 69d145be..c6888d7e 100644 --- a/kdejava/koala/kdejava/KFileDetailView.cpp +++ b/kdejava/koala/kdejava/KFileDetailView.cpp @@ -2,7 +2,7 @@ #include #include #include -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/KFileIconView.cpp b/kdejava/koala/kdejava/KFileIconView.cpp index 4b5aaf63..cb0e9b51 100644 --- a/kdejava/koala/kdejava/KFileIconView.cpp +++ b/kdejava/koala/kdejava/KFileIconView.cpp @@ -2,7 +2,7 @@ #include #include #include -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/KFilePreview.cpp b/kdejava/koala/kdejava/KFilePreview.cpp index 90eb2fca..217d290c 100644 --- a/kdejava/koala/kdejava/KFilePreview.cpp +++ b/kdejava/koala/kdejava/KFilePreview.cpp @@ -2,7 +2,7 @@ #include #include #include -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/KFileView.cpp b/kdejava/koala/kdejava/KFileView.cpp index 942e4244..2cbaa8e0 100644 --- a/kdejava/koala/kdejava/KFileView.cpp +++ b/kdejava/koala/kdejava/KFileView.cpp @@ -2,7 +2,7 @@ #include #include #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KHTMLPart.cpp b/kdejava/koala/kdejava/KHTMLPart.cpp index 6397ede3..b06200c0 100644 --- a/kdejava/koala/kdejava/KHTMLPart.cpp +++ b/kdejava/koala/kdejava/KHTMLPart.cpp @@ -3,14 +3,14 @@ #include #include #include -#include +#include #include #include #include #include #include #include -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/KHTMLSettings.cpp b/kdejava/koala/kdejava/KHTMLSettings.cpp index 78c280d9..66d4d10d 100644 --- a/kdejava/koala/kdejava/KHTMLSettings.cpp +++ b/kdejava/koala/kdejava/KHTMLSettings.cpp @@ -1,7 +1,7 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KHTMLView.cpp b/kdejava/koala/kdejava/KHTMLView.cpp index 723fed59..32896aec 100644 --- a/kdejava/koala/kdejava/KHTMLView.cpp +++ b/kdejava/koala/kdejava/KHTMLView.cpp @@ -1,6 +1,6 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMdi.cpp b/kdejava/koala/kdejava/KMdi.cpp index 5f4a3aa8..d8ca2f90 100644 --- a/kdejava/koala/kdejava/KMdi.cpp +++ b/kdejava/koala/kdejava/KMdi.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMdiChildArea.cpp b/kdejava/koala/kdejava/KMdiChildArea.cpp index a81ebcf0..8e49aa77 100644 --- a/kdejava/koala/kdejava/KMdiChildArea.cpp +++ b/kdejava/koala/kdejava/KMdiChildArea.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/KMdiChildFrm.cpp b/kdejava/koala/kdejava/KMdiChildFrm.cpp index dd154176..b7e43903 100644 --- a/kdejava/koala/kdejava/KMdiChildFrm.cpp +++ b/kdejava/koala/kdejava/KMdiChildFrm.cpp @@ -1,6 +1,6 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/KMdiChildFrmCaption.cpp b/kdejava/koala/kdejava/KMdiChildFrmCaption.cpp index 695b25cb..3f5a7794 100644 --- a/kdejava/koala/kdejava/KMdiChildFrmCaption.cpp +++ b/kdejava/koala/kdejava/KMdiChildFrmCaption.cpp @@ -1,6 +1,6 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMdiChildFrmDragBeginEvent.cpp b/kdejava/koala/kdejava/KMdiChildFrmDragBeginEvent.cpp index 2d9643e4..8438a5a9 100644 --- a/kdejava/koala/kdejava/KMdiChildFrmDragBeginEvent.cpp +++ b/kdejava/koala/kdejava/KMdiChildFrmDragBeginEvent.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMdiChildFrmDragEndEvent.cpp b/kdejava/koala/kdejava/KMdiChildFrmDragEndEvent.cpp index a0e17118..59b74509 100644 --- a/kdejava/koala/kdejava/KMdiChildFrmDragEndEvent.cpp +++ b/kdejava/koala/kdejava/KMdiChildFrmDragEndEvent.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMdiChildFrmMoveEvent.cpp b/kdejava/koala/kdejava/KMdiChildFrmMoveEvent.cpp index 6bdfb821..f68f73dd 100644 --- a/kdejava/koala/kdejava/KMdiChildFrmMoveEvent.cpp +++ b/kdejava/koala/kdejava/KMdiChildFrmMoveEvent.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMdiChildFrmResizeBeginEvent.cpp b/kdejava/koala/kdejava/KMdiChildFrmResizeBeginEvent.cpp index fa51ccf1..60e2339b 100644 --- a/kdejava/koala/kdejava/KMdiChildFrmResizeBeginEvent.cpp +++ b/kdejava/koala/kdejava/KMdiChildFrmResizeBeginEvent.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMdiChildFrmResizeEndEvent.cpp b/kdejava/koala/kdejava/KMdiChildFrmResizeEndEvent.cpp index da2152aa..c1f8ff97 100644 --- a/kdejava/koala/kdejava/KMdiChildFrmResizeEndEvent.cpp +++ b/kdejava/koala/kdejava/KMdiChildFrmResizeEndEvent.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMdiChildView.cpp b/kdejava/koala/kdejava/KMdiChildView.cpp index 1ce47560..8f7e711d 100644 --- a/kdejava/koala/kdejava/KMdiChildView.cpp +++ b/kdejava/koala/kdejava/KMdiChildView.cpp @@ -1,6 +1,6 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/KMdiMainFrm.cpp b/kdejava/koala/kdejava/KMdiMainFrm.cpp index 27dbfcb7..7181f64d 100644 --- a/kdejava/koala/kdejava/KMdiMainFrm.cpp +++ b/kdejava/koala/kdejava/KMdiMainFrm.cpp @@ -3,12 +3,12 @@ #include #include #include -#include +#include #include #include #include #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMdiTaskBar.cpp b/kdejava/koala/kdejava/KMdiTaskBar.cpp index a118b38c..c8ece526 100644 --- a/kdejava/koala/kdejava/KMdiTaskBar.cpp +++ b/kdejava/koala/kdejava/KMdiTaskBar.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMdiTaskBarButton.cpp b/kdejava/koala/kdejava/KMdiTaskBarButton.cpp index ca53cb2c..e8212341 100644 --- a/kdejava/koala/kdejava/KMdiTaskBarButton.cpp +++ b/kdejava/koala/kdejava/KMdiTaskBarButton.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMdiToolViewAccessor.cpp b/kdejava/koala/kdejava/KMdiToolViewAccessor.cpp index 445d5162..677abd0c 100644 --- a/kdejava/koala/kdejava/KMdiToolViewAccessor.cpp +++ b/kdejava/koala/kdejava/KMdiToolViewAccessor.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMdiViewCloseEvent.cpp b/kdejava/koala/kdejava/KMdiViewCloseEvent.cpp index b46d6b17..c86c3636 100644 --- a/kdejava/koala/kdejava/KMdiViewCloseEvent.cpp +++ b/kdejava/koala/kdejava/KMdiViewCloseEvent.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMdiWin32IconButton.cpp b/kdejava/koala/kdejava/KMdiWin32IconButton.cpp index c6e7c922..38ec281b 100644 --- a/kdejava/koala/kdejava/KMdiWin32IconButton.cpp +++ b/kdejava/koala/kdejava/KMdiWin32IconButton.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMultiTabBar.cpp b/kdejava/koala/kdejava/KMultiTabBar.cpp index f1ebc919..9e689f0f 100644 --- a/kdejava/koala/kdejava/KMultiTabBar.cpp +++ b/kdejava/koala/kdejava/KMultiTabBar.cpp @@ -2,7 +2,7 @@ #include #include #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMultiTabBarButton.cpp b/kdejava/koala/kdejava/KMultiTabBarButton.cpp index 1dc1a223..70f5e668 100644 --- a/kdejava/koala/kdejava/KMultiTabBarButton.cpp +++ b/kdejava/koala/kdejava/KMultiTabBarButton.cpp @@ -2,7 +2,7 @@ #include #include #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMultiTabBarTab.cpp b/kdejava/koala/kdejava/KMultiTabBarTab.cpp index 22580109..33afa189 100644 --- a/kdejava/koala/kdejava/KMultiTabBarTab.cpp +++ b/kdejava/koala/kdejava/KMultiTabBarTab.cpp @@ -1,7 +1,7 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KMultipleDrag.cpp b/kdejava/koala/kdejava/KMultipleDrag.cpp index 78a589a8..a71dbfb8 100644 --- a/kdejava/koala/kdejava/KMultipleDrag.cpp +++ b/kdejava/koala/kdejava/KMultipleDrag.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KSpell.cpp b/kdejava/koala/kdejava/KSpell.cpp index 5d47ade1..1bb6c1b3 100644 --- a/kdejava/koala/kdejava/KSpell.cpp +++ b/kdejava/koala/kdejava/KSpell.cpp @@ -1,6 +1,6 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KSpellDlg.cpp b/kdejava/koala/kdejava/KSpellDlg.cpp index 882633ea..4590383d 100644 --- a/kdejava/koala/kdejava/KSpellDlg.cpp +++ b/kdejava/koala/kdejava/KSpellDlg.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KSycoca.cpp b/kdejava/koala/kdejava/KSycoca.cpp index e5a13153..41673aa4 100644 --- a/kdejava/koala/kdejava/KSycoca.cpp +++ b/kdejava/koala/kdejava/KSycoca.cpp @@ -1,11 +1,11 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include #include #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/KSycocaEntry.cpp b/kdejava/koala/kdejava/KSycocaEntry.cpp index 8e5bb930..06529e1c 100644 --- a/kdejava/koala/kdejava/KSycocaEntry.cpp +++ b/kdejava/koala/kdejava/KSycocaEntry.cpp @@ -1,9 +1,9 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/LiveConnectExtension.cpp b/kdejava/koala/kdejava/LiveConnectExtension.cpp index ed06df0b..f1c327e7 100644 --- a/kdejava/koala/kdejava/LiveConnectExtension.cpp +++ b/kdejava/koala/kdejava/LiveConnectExtension.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/MainWindow.cpp b/kdejava/koala/kdejava/MainWindow.cpp index 84f44e34..b3905615 100644 --- a/kdejava/koala/kdejava/MainWindow.cpp +++ b/kdejava/koala/kdejava/MainWindow.cpp @@ -1,7 +1,7 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/Makefile.am b/kdejava/koala/kdejava/Makefile.am index d2df9c4f..70da0cc0 100644 --- a/kdejava/koala/kdejava/Makefile.am +++ b/kdejava/koala/kdejava/Makefile.am @@ -33,6 +33,6 @@ noinst_HEADERS = KDESupport.h KDEJavaSlot.h libkdejava_la_LDFLAGS = $(all_libraries) -no-undefined -version-info $(SOMAJOR):$(SOMINOR):$(SOSUBMINOR) -libkdejava_la_LIBADD = $(top_builddir)/qtjava/javalib/qtjava/libqtjavasupport.la -lkmdi $(LIB_KHTML) $(LIB_KSPELL) $(LIB_KIO) $(LIB_TDECORE) $(LIB_KPARTS) $(LIB_TDEUI) $(LIB_KUTILS) $(LIB_TDEPRINT) -lDCOP -ltdefx +libkdejava_la_LIBADD = $(top_builddir)/qtjava/javalib/qtjava/libqtjavasupport.la -ltdemdi $(LIB_KHTML) $(LIB_KSPELL) $(LIB_KIO) $(LIB_TDECORE) $(LIB_KPARTS) $(LIB_TDEUI) $(LIB_KUTILS) $(LIB_TDEPRINT) -lDCOP -ltdefx KDE_OPTIONS = qtonly nofinal diff --git a/kdejava/koala/kdejava/MetaInfoJob.cpp b/kdejava/koala/kdejava/MetaInfoJob.cpp index 0887597c..b02493ce 100644 --- a/kdejava/koala/kdejava/MetaInfoJob.cpp +++ b/kdejava/koala/kdejava/MetaInfoJob.cpp @@ -1,6 +1,6 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/OpenURLEvent.cpp b/kdejava/koala/kdejava/OpenURLEvent.cpp index 37076d72..221137bc 100644 --- a/kdejava/koala/kdejava/OpenURLEvent.cpp +++ b/kdejava/koala/kdejava/OpenURLEvent.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/Part.cpp b/kdejava/koala/kdejava/Part.cpp index c1a75faa..e62da8a6 100644 --- a/kdejava/koala/kdejava/Part.cpp +++ b/kdejava/koala/kdejava/Part.cpp @@ -1,7 +1,7 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/PartActivateEvent.cpp b/kdejava/koala/kdejava/PartActivateEvent.cpp index d40a4e8a..fbb3cd20 100644 --- a/kdejava/koala/kdejava/PartActivateEvent.cpp +++ b/kdejava/koala/kdejava/PartActivateEvent.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/PartBase.cpp b/kdejava/koala/kdejava/PartBase.cpp index be497590..5d9b03e0 100644 --- a/kdejava/koala/kdejava/PartBase.cpp +++ b/kdejava/koala/kdejava/PartBase.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/PartManager.cpp b/kdejava/koala/kdejava/PartManager.cpp index 01d6dab5..08c48f7c 100644 --- a/kdejava/koala/kdejava/PartManager.cpp +++ b/kdejava/koala/kdejava/PartManager.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/PartSelectEvent.cpp b/kdejava/koala/kdejava/PartSelectEvent.cpp index 0e50bc49..1efabfe1 100644 --- a/kdejava/koala/kdejava/PartSelectEvent.cpp +++ b/kdejava/koala/kdejava/PartSelectEvent.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/Plugin.cpp b/kdejava/koala/kdejava/Plugin.cpp index e516137a..6e7ca8e1 100644 --- a/kdejava/koala/kdejava/Plugin.cpp +++ b/kdejava/koala/kdejava/Plugin.cpp @@ -1,6 +1,6 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/PreviewJob.cpp b/kdejava/koala/kdejava/PreviewJob.cpp index 0997bbc8..7ea76580 100644 --- a/kdejava/koala/kdejava/PreviewJob.cpp +++ b/kdejava/koala/kdejava/PreviewJob.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/ReadOnlyPart.cpp b/kdejava/koala/kdejava/ReadOnlyPart.cpp index 712df487..db8a1870 100644 --- a/kdejava/koala/kdejava/ReadOnlyPart.cpp +++ b/kdejava/koala/kdejava/ReadOnlyPart.cpp @@ -1,6 +1,6 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include diff --git a/kdejava/koala/kdejava/ReadWritePart.cpp b/kdejava/koala/kdejava/ReadWritePart.cpp index 130e196a..890ace43 100644 --- a/kdejava/koala/kdejava/ReadWritePart.cpp +++ b/kdejava/koala/kdejava/ReadWritePart.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/StatusBarExtension.cpp b/kdejava/koala/kdejava/StatusBarExtension.cpp index 330a89a6..b92234e7 100644 --- a/kdejava/koala/kdejava/StatusBarExtension.cpp +++ b/kdejava/koala/kdejava/StatusBarExtension.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/TDEIO.cpp b/kdejava/koala/kdejava/TDEIO.cpp index 12aeca9d..5e94eb16 100644 --- a/kdejava/koala/kdejava/TDEIO.cpp +++ b/kdejava/koala/kdejava/TDEIO.cpp @@ -1,12 +1,12 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include #include -#include +#include #include #include #include #include -#include +#include #include #include #include diff --git a/kdejava/koala/kdejava/URLArgs.cpp b/kdejava/koala/kdejava/URLArgs.cpp index d6a85867..1c0ced4b 100644 --- a/kdejava/koala/kdejava/URLArgs.cpp +++ b/kdejava/koala/kdejava/URLArgs.cpp @@ -1,5 +1,5 @@ //Auto-generated by kalyptus. DO NOT EDIT. -#include +#include #include #include diff --git a/kdejava/koala/kdejava/WindowArgs.cpp b/kdejava/koala/kdejava/WindowArgs.cpp index 325f5cf3..bf5e0c3e 100644 --- a/kdejava/koala/kdejava/WindowArgs.cpp +++ b/kdejava/koala/kdejava/WindowArgs.cpp @@ -1,6 +1,6 @@ //Auto-generated by kalyptus. DO NOT EDIT. #include -#include +#include #include #include diff --git a/kdejava/koala/org/kde/koala/Element.java b/kdejava/koala/org/kde/koala/Element.java index 4edb66e3..80c809b1 100644 --- a/kdejava/koala/org/kde/koala/Element.java +++ b/kdejava/koala/org/kde/koala/Element.java @@ -317,10 +317,10 @@ public class Element extends Node { @short KHTML extension to DOM This method returns the associated form element. */ public native Element form(); - public static native boolean khtmlValidAttrName(String name); - public static native boolean khtmlValidPrefix(String name); - public static native boolean khtmlValidQualifiedName(String name); - public static native boolean khtmlMalformedQualifiedName(String name); - public static native boolean khtmlMalformedPrefix(String name); + public static native boolean tdehtmlValidAttrName(String name); + public static native boolean tdehtmlValidPrefix(String name); + public static native boolean tdehtmlValidQualifiedName(String name); + public static native boolean tdehtmlMalformedQualifiedName(String name); + public static native boolean tdehtmlMalformedPrefix(String name); // DOM::Element* Element(DOM::ElementImpl* arg1); >>>> NOT CONVERTED } diff --git a/kdejava/koala/org/kde/koala/Factory.java b/kdejava/koala/org/kde/koala/Factory.java index 80be6662..912d7454 100644 --- a/kdejava/koala/org/kde/koala/Factory.java +++ b/kdejava/koala/org/kde/koala/Factory.java @@ -25,7 +25,7 @@ public class Factory extends KLibFactory { The ArrayList can be used to pass additional arguments to the part. If the part needs additional arguments, it should take them as name="value" pairs. This is the way additional arguments will get passed - to the part from eg. khtml. You can for example embed the part into HTML + to the part from eg. tdehtml. You can for example embed the part into HTML by using the following code:
 		    
diff --git a/kdejava/koala/org/kde/koala/HistoryProvider.java b/kdejava/koala/org/kde/koala/HistoryProvider.java
index b40c8799..5f101526 100644
--- a/kdejava/koala/org/kde/koala/HistoryProvider.java
+++ b/kdejava/koala/org/kde/koala/HistoryProvider.java
@@ -12,9 +12,9 @@ import org.kde.qt.TQObject;
  Basic class to manage a history of "items". This class is only meant
  for fast lookup, if an item is in the history or not.
  May be subclassed to implement a persistent history for example.
- For usage with khtml, just create your provider and call the
- HistoryProvider constructor _before_ you do any khtml stuff. That way,
- khtml, using the self()-method, will use your subclassed provider.
+ For usage with tdehtml, just create your provider and call the
+ HistoryProvider constructor _before_ you do any tdehtml stuff. That way,
+ tdehtml, using the self()-method, will use your subclassed provider.
  See {@link HistoryProviderSignals} for signals emitted by HistoryProvider
 		@author Carsten Pfeiffer 
  
diff --git a/kdejava/koala/org/kde/koala/KServiceGroup.java b/kdejava/koala/org/kde/koala/KServiceGroup.java
index fcbb89ef..a76f60a3 100644
--- a/kdejava/koala/org/kde/koala/KServiceGroup.java
+++ b/kdejava/koala/org/kde/koala/KServiceGroup.java
@@ -122,7 +122,7 @@ public class KServiceGroup extends KSycocaEntry  {
 	public native int childCount();
 	/**	
 		 Returns true if the NoDisplay flag was set, i.e. if this
-		 group should be hidden from menus, while still being in ksycoca.
+		 group should be hidden from menus, while still being in tdesycoca.
 				@return true to hide this service group, false to display it
 
 		@short    Returns true if the NoDisplay flag was set, i.
diff --git a/kdejava/koala/org/kde/koala/KSpell.java b/kdejava/koala/org/kde/koala/KSpell.java
index 3ea6d3e0..a1535e00 100644
--- a/kdejava/koala/org/kde/koala/KSpell.java
+++ b/kdejava/koala/org/kde/koala/KSpell.java
@@ -243,7 +243,7 @@ public class KSpell extends TQObject  {
 			 After calling checkWord, you can use this to get the dialog box's
 		  result code.
 		 The possible
-		  values are (from kspelldlg.h):
+		  values are (from tdespelldlg.h):
 		
 			
  • KS_CANCEL diff --git a/kdejava/koala/org/kde/koala/KSpellConfig.java b/kdejava/koala/org/kde/koala/KSpellConfig.java index c5cf1e85..57b018dd 100644 --- a/kdejava/koala/org/kde/koala/KSpellConfig.java +++ b/kdejava/koala/org/kde/koala/KSpellConfig.java @@ -178,8 +178,8 @@ public class KSpellConfig extends TQWidget { */ protected native boolean interpret(StringBuffer fname, StringBuffer lname, StringBuffer hname); /** - Invokes the help documentation for kspell - @short Invokes the help documentation for kspell + Invokes the help documentation for tdespell + @short Invokes the help documentation for tdespell */ protected native void sHelp(); protected native void sNoAff(boolean arg1); diff --git a/kdejava/koala/org/kde/koala/KStringHandler.java b/kdejava/koala/org/kde/koala/KStringHandler.java index 6897854a..3e271c22 100644 --- a/kdejava/koala/org/kde/koala/KStringHandler.java +++ b/kdejava/koala/org/kde/koala/KStringHandler.java @@ -327,8 +327,8 @@ public class KStringHandler implements QtSupport { will be extracted. The final token will be the remainder of the string. Example:
    -		 perlSplit(' ', "kparts reaches the parts other parts can't", 3)
    -		 ArrayList contains: "kparts", "reaches", "the parts other parts can't"
    +		 perlSplit(' ', "tdeparts reaches the parts other parts can't", 3)
    +		 ArrayList contains: "tdeparts", "reaches", "the parts other parts can't"
     		 
    @param sep is the character to use to delimit s. @param s is the input string diff --git a/kdejava/koala/org/kde/koala/KSycoca.java b/kdejava/koala/org/kde/koala/KSycoca.java index ea1317c1..6386cafa 100644 --- a/kdejava/koala/org/kde/koala/KSycoca.java +++ b/kdejava/koala/org/kde/koala/KSycoca.java @@ -54,7 +54,7 @@ public class KSycoca extends TQObject implements DCOPObjectInterface { public native int timeStamp(); /** Signature that keeps track of changes to - $TDEDIR/share/services/update_ksycoca + $TDEDIR/share/services/update_tdesycoca Touching this file causes the database to be recreated from scratch. @short diff --git a/kdejava/koala/org/kde/koala/KSycocaEntry.java b/kdejava/koala/org/kde/koala/KSycocaEntry.java index a7695d3d..89efbcec 100644 --- a/kdejava/koala/org/kde/koala/KSycocaEntry.java +++ b/kdejava/koala/org/kde/koala/KSycocaEntry.java @@ -11,7 +11,7 @@ import org.kde.qt.TQDataStream; You can't create an instance of KSycocaEntry, but it provides the common functionality for servicetypes and services. @short Base class for all Sycoca entries. - @see #http://developer#kde#org/documentation/library/kdeqt/trinityarch/ksycoca#html + @see #http://developer#kde#org/documentation/library/kdeqt/trinityarch/tdesycoca#html */ public class KSycocaEntry extends KShared { diff --git a/kdejava/koala/org/kde/koala/KTrader.java b/kdejava/koala/org/kde/koala/KTrader.java index 8b28f6c2..db0fdb0a 100644 --- a/kdejava/koala/org/kde/koala/KTrader.java +++ b/kdejava/koala/org/kde/koala/KTrader.java @@ -19,7 +19,7 @@ import org.kde.qt.TQObject; \par Examples A few examples will make this a lot more clear. Say you have an application that will display HTML. In this - example, you don't want to link to khtml... and furthermore, you + example, you don't want to link to tdehtml... and furthermore, you really don't care if the HTML browser is ours or not, as long as it works. The way that you formulate your query as well as the way that you execute the browser depends on whether or not you want the diff --git a/kdejava/koala/org/kde/koala/Part.java b/kdejava/koala/org/kde/koala/Part.java index 9bd399c7..179e67b7 100644 --- a/kdejava/koala/org/kde/koala/Part.java +++ b/kdejava/koala/org/kde/koala/Part.java @@ -96,7 +96,7 @@ public class Part extends TQObject implements PartBaseInterface { Returns the part (this, or a child part) at the given global position. This is called by the part manager to ask whether a part should be activated when clicking somewhere. In most cases the default implementation is enough. - Reimplement this if your part has child parts in some areas (like in khtml or koffice) + Reimplement this if your part has child parts in some areas (like in tdehtml or koffice) @param widget the part widget being clicked - usually the same as widget(), except in koffice. @param globalPos the mouse coordinates in global coordinates @short Returns the part (this, or a child part) at the given global position. diff --git a/kdejava/koala/test/simplebrowser/KSimpleBrowser.java b/kdejava/koala/test/simplebrowser/KSimpleBrowser.java index 051dfeab..3af57ba5 100644 --- a/kdejava/koala/test/simplebrowser/KSimpleBrowser.java +++ b/kdejava/koala/test/simplebrowser/KSimpleBrowser.java @@ -23,7 +23,7 @@ public class KSimpleBrowser extends KMainWindow { static final int URLLined = 1; - KHTMLPart khtmlpart; + KHTMLPart tdehtmlpart; public KSimpleBrowser (String name) { @@ -35,25 +35,25 @@ public class KSimpleBrowser extends KMainWindow { toolBar().setItemAutoSized(URLLined); - khtmlpart = new KHTMLPart(this); - khtmlpart.begin(); + tdehtmlpart = new KHTMLPart(this); + tdehtmlpart.begin(); - khtmlpart.write("

    KSimpleBrowser

    " + + tdehtmlpart.write("

    KSimpleBrowser

    " + "

    To load a web page, type its URL in the line " + "edit box and press enter,

    " + ""); - khtmlpart.end(); + tdehtmlpart.end(); setCaption("KDE 2 Development book example - KSimpleBrowser"); - setCentralWidget(khtmlpart.view()); + setCentralWidget(tdehtmlpart.view()); } public void slotNewURL () { - khtmlpart.openURL(new KURL(this.toolBar().getLinedText(URLLined))) ; + tdehtmlpart.openURL(new KURL(this.toolBar().getLinedText(URLLined))) ; } diff --git a/kjsembed/Makefile.am b/kjsembed/Makefile.am index 3399ffb6..ad4b48f4 100644 --- a/kjsembed/Makefile.am +++ b/kjsembed/Makefile.am @@ -6,7 +6,7 @@ INCLUDES = -I$(QTDIR)/tools/designer/uilib -I$(srcdir)/.. $(all_includes) INCLUDES += -DQT_CLEAN_NAMESPACE -DQT_NO_ASCII_CAST -SUBDIRS = bindings builtins qtbindings . plugin plugins kscript stdlib cpptests docs +SUBDIRS = bindings builtins qtbindings . plugin plugins tdescript stdlib cpptests docs lib_LTLIBRARIES = libkjsembed.la bin_PROGRAMS = kjscmd diff --git a/kjsembed/builtins/Makefile.am b/kjsembed/builtins/Makefile.am index bf12fcf8..5be761af 100644 --- a/kjsembed/builtins/Makefile.am +++ b/kjsembed/builtins/Makefile.am @@ -11,7 +11,7 @@ libkjsembedbuiltins_la_SOURCES = stdaction_imp.cpp \ qdir_imp.cpp \ qfile_imp.cpp -libkjsembedbuiltins_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -lktexteditor +libkjsembedbuiltins_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor libkjsembedbuiltins_la_LIBADD = $(LIB_QT) $(LIB_TDECORE) $(LIB_TDEUI) $(LIB_KPARTS) \ $(LIB_KFILE) -lkjs $(LIBSOCKET) diff --git a/kjsembed/customobject_imp.cpp b/kjsembed/customobject_imp.cpp index 04b20c68..ab006c77 100644 --- a/kjsembed/customobject_imp.cpp +++ b/kjsembed/customobject_imp.cpp @@ -45,7 +45,7 @@ #ifndef QT_ONLY -#include +#include #include #include @@ -435,14 +435,14 @@ KJS::Value CustomObjectImp::call( KJS::ExecState *exec, KJS::Object &self, const return KJS::Value(); break; case KHTMLPartSelectAll: - khtmlPartSelectAll( exec, self, args ); + tdehtmlPartSelectAll( exec, self, args ); return KJS::Value(); break; case KHTMLPartHasSelection: - return khtmlPartHasSelection( exec, self, args ); + return tdehtmlPartHasSelection( exec, self, args ); break; case KHTMLPartSelectedText: - return khtmlPartSelectedText( exec, self, args ); + return tdehtmlPartSelectedText( exec, self, args ); break; case KSystemTrayContextMenu: return ksystemtrayContextMenu( exec, self, args ); @@ -1094,7 +1094,7 @@ void CustomObjectImp::hboxSpacing( KJS::ExecState *exec, KJS::Object &, const KJ box->setSpacing( extractInt( exec, args, 0 ) ); } -void CustomObjectImp::khtmlPartSelectAll( KJS::ExecState *, KJS::Object &, const KJS::List & ) +void CustomObjectImp::tdehtmlPartSelectAll( KJS::ExecState *, KJS::Object &, const KJS::List & ) { #ifndef QT_ONLY @@ -1105,7 +1105,7 @@ void CustomObjectImp::khtmlPartSelectAll( KJS::ExecState *, KJS::Object &, const #endif // QT_ONLY } -KJS::Value CustomObjectImp::khtmlPartHasSelection( KJS::ExecState *, KJS::Object &, const KJS::List & ) +KJS::Value CustomObjectImp::tdehtmlPartHasSelection( KJS::ExecState *, KJS::Object &, const KJS::List & ) { #ifndef QT_ONLY @@ -1118,7 +1118,7 @@ KJS::Value CustomObjectImp::khtmlPartHasSelection( KJS::ExecState *, KJS::Object return KJS::Null(); } -KJS::Value CustomObjectImp::khtmlPartSelectedText( KJS::ExecState *, KJS::Object &, const KJS::List & ) +KJS::Value CustomObjectImp::tdehtmlPartSelectedText( KJS::ExecState *, KJS::Object &, const KJS::List & ) { #ifndef QT_ONLY diff --git a/kjsembed/customobject_imp.h b/kjsembed/customobject_imp.h index 600d7a15..2b11686c 100644 --- a/kjsembed/customobject_imp.h +++ b/kjsembed/customobject_imp.h @@ -172,9 +172,9 @@ public: void hboxSpacing( KJS::ExecState *exec, KJS::Object &, const KJS::List &args ); - void khtmlPartSelectAll( KJS::ExecState *, KJS::Object &, const KJS::List & ); - KJS::Value khtmlPartHasSelection( KJS::ExecState *, KJS::Object &, const KJS::List & ); - KJS::Value khtmlPartSelectedText( KJS::ExecState *, KJS::Object &, const KJS::List &args ); + void tdehtmlPartSelectAll( KJS::ExecState *, KJS::Object &, const KJS::List & ); + KJS::Value tdehtmlPartHasSelection( KJS::ExecState *, KJS::Object &, const KJS::List & ); + KJS::Value tdehtmlPartSelectedText( KJS::ExecState *, KJS::Object &, const KJS::List &args ); KJS::Value ksystemtrayContextMenu( KJS::ExecState *exec, KJS::Object&, const KJS::List &args ); KJS::Value ksystemtrayActionCollection( KJS::ExecState *exec, KJS::Object&, const KJS::List &args ); diff --git a/kjsembed/docs/ChangeLog b/kjsembed/docs/ChangeLog index 0c19114f..4b14af71 100644 --- a/kjsembed/docs/ChangeLog +++ b/kjsembed/docs/ChangeLog @@ -1351,7 +1351,7 @@ 2004-04-09 Friday 21:26 rich Added support for streaming data to a KPart, and an example of doing so. This - means you no longer need to have a temporary file to display stuff in khtml. + means you no longer need to have a temporary file to display stuff in tdehtml. 2004-04-09 Friday 20:22 rich diff --git a/kjsembed/docs/embedding/simple-embed/Makefile.am b/kjsembed/docs/embedding/simple-embed/Makefile.am index 2c9243a3..93d68f76 100644 --- a/kjsembed/docs/embedding/simple-embed/Makefile.am +++ b/kjsembed/docs/embedding/simple-embed/Makefile.am @@ -8,7 +8,7 @@ bin_PROGRAMS = embedjs INCLUDES = -I$(top_srcdir) $(all_includes) # the library search path. -embedjs_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -lktexteditor +embedjs_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor # the libraries to link against. embedjs_LDADD = $(LIB_KFILE) $(LIB_TDEPRINT) -lkjs $(top_builddir)/kjsembed/libkjsembed.la diff --git a/kjsembed/docs/embedding/simple-embed/README b/kjsembed/docs/embedding/simple-embed/README index 9c048f35..12f9642b 100644 --- a/kjsembed/docs/embedding/simple-embed/README +++ b/kjsembed/docs/embedding/simple-embed/README @@ -53,7 +53,7 @@ embeddable in other apps. For example, the kmplayer kpart can be called to play in your app. For more details, consult : -http://www-106.ibm.com/developerworks/library/l-kparts/ +http://www-106.ibm.com/developerworks/library/l-tdeparts/ http://developer.kde.org/documentation/tutorials/dot/writing-plugins.html http://developer.kde.org/documentation/tutorials/developing-a-plugin-structure/index.html diff --git a/kjsembed/jsfactory.cpp b/kjsembed/jsfactory.cpp index 5e6a22a7..d5be63a9 100644 --- a/kjsembed/jsfactory.cpp +++ b/kjsembed/jsfactory.cpp @@ -54,9 +54,9 @@ #include #include -#include -#include -#include +#include +#include +#include #endif // QT_ONLY diff --git a/kjsembed/kjsembedpart.h b/kjsembed/kjsembedpart.h index 84080138..3e4b3afb 100644 --- a/kjsembed/kjsembedpart.h +++ b/kjsembed/kjsembedpart.h @@ -25,7 +25,7 @@ #include #ifndef QT_ONLY -#include +#include #endif #include diff --git a/kjsembed/plugin/jsconsoleplugin.cpp b/kjsembed/plugin/jsconsoleplugin.cpp index 15e67506..c1e4026c 100644 --- a/kjsembed/plugin/jsconsoleplugin.cpp +++ b/kjsembed/plugin/jsconsoleplugin.cpp @@ -23,7 +23,7 @@ #include #include #include -#include +#include #include #include diff --git a/kjsembed/plugin/jsconsoleplugin.h b/kjsembed/plugin/jsconsoleplugin.h index 18a17ed9..c8ea7aef 100644 --- a/kjsembed/plugin/jsconsoleplugin.h +++ b/kjsembed/plugin/jsconsoleplugin.h @@ -22,7 +22,7 @@ #ifndef KJSEMBEDJSCONSOLEPLUGIN_H #define KJSEMBEDJSCONSOLEPLUGIN_H -#include +#include class KJSEmbedPart; diff --git a/kjsembed/kscript/Makefile.am b/kjsembed/tdescript/Makefile.am similarity index 90% rename from kjsembed/kscript/Makefile.am rename to kjsembed/tdescript/Makefile.am index 2efe1a79..adcf52d4 100644 --- a/kjsembed/kscript/Makefile.am +++ b/kjsembed/tdescript/Makefile.am @@ -4,7 +4,7 @@ kde_module_LTLIBRARIES = libjavascript.la libjavascript_la_SOURCES = javascript.cpp libjavascript_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN) -lDCOP -ltdecore -ltdeui $(LIB_QT) -lkjs -ltdefx -no-undefined -avoid-version -libjavascript_la_LIBADD = -lkscript ../libkjsembed.la +libjavascript_la_LIBADD = -ltdescript ../libkjsembed.la METASOURCES = AUTO diff --git a/kjsembed/kscript/javascript.cpp b/kjsembed/tdescript/javascript.cpp similarity index 100% rename from kjsembed/kscript/javascript.cpp rename to kjsembed/tdescript/javascript.cpp diff --git a/kjsembed/kscript/javascript.desktop b/kjsembed/tdescript/javascript.desktop similarity index 100% rename from kjsembed/kscript/javascript.desktop rename to kjsembed/tdescript/javascript.desktop diff --git a/kjsembed/kscript/javascript.h b/kjsembed/tdescript/javascript.h similarity index 100% rename from kjsembed/kscript/javascript.h rename to kjsembed/tdescript/javascript.h diff --git a/kjsembed/kscript/swaptabs.desktop b/kjsembed/tdescript/swaptabs.desktop similarity index 100% rename from kjsembed/kscript/swaptabs.desktop rename to kjsembed/tdescript/swaptabs.desktop diff --git a/kjsembed/kscript/swaptabs.js b/kjsembed/tdescript/swaptabs.js similarity index 100% rename from kjsembed/kscript/swaptabs.js rename to kjsembed/tdescript/swaptabs.js diff --git a/kjsembed/kscript/swaptabs.ui b/kjsembed/tdescript/swaptabs.ui similarity index 100% rename from kjsembed/kscript/swaptabs.ui rename to kjsembed/tdescript/swaptabs.ui diff --git a/kjsembed/tests/test_kparts_args.js b/kjsembed/tests/test_tdeparts_args.js similarity index 100% rename from kjsembed/tests/test_kparts_args.js rename to kjsembed/tests/test_tdeparts_args.js diff --git a/korundum/bin/Makefile.am b/korundum/bin/Makefile.am index 4c3e637c..69813941 100644 --- a/korundum/bin/Makefile.am +++ b/korundum/bin/Makefile.am @@ -1,7 +1,7 @@ INCLUDES = $(all_includes) -I$(RUBY_ARCHDIR) $(RUBY_CFLAGS) bin_PROGRAMS = krubyinit -krubyinit_LDFLAGS = -module $(all_libraries) -version-info 0:0:0 -L$(top_srcdir)/smoke/kde/ -L$(RUBY_LIBDIR) -lkmdi -lknewstuff +krubyinit_LDFLAGS = -module $(all_libraries) -version-info 0:0:0 -L$(top_srcdir)/smoke/kde/ -L$(RUBY_LIBDIR) -ltdemdi -lknewstuff krubyinit_METASOURCES = AUTO krubyinit_SOURCES = krubyinit.cpp krubyinit_LDADD = $(LIB_KDE) $(RUBY_LIBRUBYARG) $(top_builddir)/smoke/kde/libsmokekde.la $(top_builddir)/qtruby/rubylib/qtruby/libqtrubyinternal.la diff --git a/korundum/rubylib/examples/RubberDoc.rb b/korundum/rubylib/examples/RubberDoc.rb index 1b196999..a5cc35cb 100755 --- a/korundum/rubylib/examples/RubberDoc.rb +++ b/korundum/rubylib/examples/RubberDoc.rb @@ -183,7 +183,7 @@ module MyGui TQt::Object.connect @listbox, SIGNAL("clicked(TQListBoxItem*)"), self, SLOT("clicked_result(TQListBoxItem*)") TQt::Object.connect @viewed, SIGNAL("completed()"), - self, SLOT("khtml_part_init_complete()") + self, SLOT("tdehtml_part_init_complete()") TQt::Object::connect @viewed, SIGNAL("setWindowCaption(const TQString&)"), @viewed.widget.topLevelWidget, @@ -501,7 +501,7 @@ module HTMLIndexer end -# TODO - this sucks, use khtml to get the values +# TODO - this sucks, use tdehtml to get the values module IDS A = 1 META = 62 @@ -865,7 +865,7 @@ end class RubberDoc < TQt::VBox - slots "khtml_part_init_complete()", + slots "tdehtml_part_init_complete()", "go_back()", "go_forward()", "go_home()", "goto_url()", "goto_search()", "clicked_result(TQListBoxItem*)", "search(const TQString&)", "update_highlight()", @@ -926,20 +926,20 @@ class RubberDoc < TQt::VBox def blah_blah save_indexes init_blah - khtml_part_init_complete + tdehtml_part_init_complete end def quit @main.close end - def khtml_part_init_complete + def tdehtml_part_init_complete TQt::Object.disconnect @viewed, SIGNAL("completed()"), - self, SLOT("khtml_part_init_complete()") if @init_connected + self, SLOT("tdehtml_part_init_complete()") if @init_connected @pref = File.dirname first_url.url.gsub("file:","") - init_khtml_part_settings @viewed if @init_connected + init_tdehtml_part_settings @viewed if @init_connected index_documents # maybe make a better choice as to the start page??? @@ -959,11 +959,11 @@ class RubberDoc < TQt::VBox save_indexes end - def init_khtml_part_settings khtmlpart - khtmlpart.setJScriptEnabled true - khtmlpart.setJavaEnabled false - khtmlpart.setPluginsEnabled false - khtmlpart.setAutoloadImages false + def init_tdehtml_part_settings tdehtmlpart + tdehtmlpart.setJScriptEnabled true + tdehtmlpart.setJavaEnabled false + tdehtmlpart.setPluginsEnabled false + tdehtmlpart.setAutoloadImages false end def load_page @@ -1248,7 +1248,7 @@ can't get tabwidget working. umm... wonder what i'm messing up... (RECHECK) # possible BUG DOM::Text.new(node).data.string # strange that this one doesn't work... (RECHECK) -wierd khtml bug +wierd tdehtml bug @rightpane.setResizeMode @viewed, TQt::Splitter::KeepSize in order to use KURL's as constants one must place this TDEApplication init diff --git a/korundum/rubylib/examples/uikmdi.rb b/korundum/rubylib/examples/uitdemdi.rb similarity index 97% rename from korundum/rubylib/examples/uikmdi.rb rename to korundum/rubylib/examples/uitdemdi.rb index e73422eb..3b67b9e1 100644 --- a/korundum/rubylib/examples/uikmdi.rb +++ b/korundum/rubylib/examples/uitdemdi.rb @@ -8,7 +8,7 @@ related to KMDI, and not the bindings. =begin A rough Python translation of the ideas presented in this KMDI tutorial: - http://web.tiscali.it/andreabergia/kmditutorial.html + http://web.tiscali.it/andreabergia/tdemditutorial.html What does work: @@ -58,7 +58,7 @@ class KmdiExample < KDE::MdiMainFrm quitAction = StdAction.quit(self, SLOT('close()'), actionCollection()) closeAction = StdAction.close(self, SLOT('closeActiveChild()'), actionCollection()) - uifilebase = Dir.getwd + '/uikmdi.rc' + uifilebase = Dir.getwd + '/uitdemdi.rc' createGUI(uifilebase) # The task bar is created in the KMdiMainFrm constructor # and then deleted in the createGUI() call above.. @@ -167,7 +167,7 @@ class KmdiExample < KDE::MdiMainFrm end if $0 == __FILE__ - aname = 'uikmdi' + aname = 'uitdemdi' desc = 'A Simple Korundum KMDI Sample' ver = '1.0' lic = AboutData::License_GPL diff --git a/korundum/rubylib/examples/uikmdi.rc b/korundum/rubylib/examples/uitdemdi.rc similarity index 100% rename from korundum/rubylib/examples/uikmdi.rc rename to korundum/rubylib/examples/uitdemdi.rc diff --git a/korundum/rubylib/korundum/Korundum.cpp b/korundum/rubylib/korundum/Korundum.cpp index c07c29c5..c6c9a548 100644 --- a/korundum/rubylib/korundum/Korundum.cpp +++ b/korundum/rubylib/korundum/Korundum.cpp @@ -30,7 +30,7 @@ #include #endif #include -#include +#include #include #include @@ -916,8 +916,8 @@ extern VALUE qt_internal_module; extern VALUE qt_base_class; extern VALUE kde_module; extern VALUE kio_module; -extern VALUE kparts_module; -extern VALUE khtml_module; +extern VALUE tdeparts_module; +extern VALUE tdehtml_module; VALUE getdcopinfo(VALUE self, TQString & signalname) diff --git a/korundum/rubylib/korundum/kdehandlers.cpp b/korundum/rubylib/korundum/kdehandlers.cpp index 1e4eb3a4..fa696791 100644 --- a/korundum/rubylib/korundum/kdehandlers.cpp +++ b/korundum/rubylib/korundum/kdehandlers.cpp @@ -26,7 +26,7 @@ #include #include #include -#include +#include #include #include #include @@ -36,8 +36,8 @@ #include #include #include -#include -#include +#include +#include #include #include #include diff --git a/korundum/rubylib/rbkconfig_compiler/Makefile.am b/korundum/rubylib/rbkconfig_compiler/Makefile.am index 7b5bd663..276e32f7 100644 --- a/korundum/rubylib/rbkconfig_compiler/Makefile.am +++ b/korundum/rubylib/rbkconfig_compiler/Makefile.am @@ -12,7 +12,7 @@ AM_CPPFLAGS = -I$(top_srcdir)/tdecore -I$(top_srcdir) $(all_includes) bin_PROGRAMS = rbkconfig_compiler -rbkconfig_compiler_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -lktexteditor +rbkconfig_compiler_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor rbkconfig_compiler_LDADD = $(LIB_TDECORE) rbkconfig_compiler_SOURCES = rbkconfig_compiler.cpp diff --git a/qtruby/ChangeLog b/qtruby/ChangeLog index 3e402418..2c5b3013 100644 --- a/qtruby/ChangeLog +++ b/qtruby/ChangeLog @@ -481,7 +481,7 @@ 2005-02-21 Richard Dale * Upped the version to 1.0.7 for the KDE 3.4 release - * Removed the khtml:: namespace as it wasn't being used + * Removed the tdehtml:: namespace as it wasn't being used 2005-02-07 Richard Dale @@ -1365,7 +1365,7 @@ 2003-10-11 Richard Dale - * Added khtml:: namespace, although it isn't in the SmokeKDE runtime yet + * Added tdehtml:: namespace, although it isn't in the SmokeKDE runtime yet * Improved method_missing error messages if a method can't be resolved 2003-10-09 Richard Dale diff --git a/qtruby/rubylib/qtruby/Qt.cpp b/qtruby/rubylib/qtruby/Qt.cpp index ad0241fc..90cd759e 100644 --- a/qtruby/rubylib/qtruby/Qt.cpp +++ b/qtruby/rubylib/qtruby/Qt.cpp @@ -98,13 +98,13 @@ extern "C" { VALUE qt_module = Qnil; VALUE qext_scintilla_module = Qnil; VALUE kde_module = Qnil; -VALUE kparts_module = Qnil; +VALUE tdeparts_module = Qnil; VALUE kio_module = Qnil; VALUE kns_module = Qnil; VALUE dom_module = Qnil; VALUE kontact_module = Qnil; VALUE kate_module = Qnil; -VALUE ktexteditor_module = Qnil; +VALUE tdetexteditor_module = Qnil; VALUE koffice_module = Qnil; VALUE qt_internal_module = Qnil; VALUE qt_base_class = Qnil; @@ -2690,7 +2690,7 @@ static TQRegExp * scope_op = 0; klass = rb_define_class_under(kde_module, package+strlen("KDE::"), base_class); rb_define_singleton_method(klass, "new", (VALUE (*) (...)) _new_kde, -1); } else if (packageName.startsWith("KParts::")) { - klass = rb_define_class_under(kparts_module, package+strlen("KParts::"), base_class); + klass = rb_define_class_under(tdeparts_module, package+strlen("KParts::"), base_class); rb_define_singleton_method(klass, "new", (VALUE (*) (...)) _new_kde, -1); if (packageName == "KParts::ReadOnlyPart") { konsole_part_class = rb_define_class_under(kde_module, "KonsolePart", klass); @@ -2720,7 +2720,7 @@ static TQRegExp * scope_op = 0; klass = rb_define_class_under(kate_module, package+strlen("Kate"), base_class); rb_define_singleton_method(klass, "new", (VALUE (*) (...)) _new_kde, -1); } else if (packageName.startsWith("KTextEditor::")) { - klass = rb_define_class_under(ktexteditor_module, package+strlen("KTextEditor::"), base_class); + klass = rb_define_class_under(tdetexteditor_module, package+strlen("KTextEditor::"), base_class); rb_define_singleton_method(klass, "new", (VALUE (*) (...)) _new_kde, -1); } else if (scope_op->search(packageName) != -1) { // If an unrecognised classname of the form 'XXXXXX::YYYYYY' is found, @@ -2831,9 +2831,9 @@ set_new_kde(VALUE (*new_kde) (int, VALUE *, VALUE)) rb_define_singleton_method(kde_module, "method_missing", (VALUE (*) (...)) kde_module_method_missing, -1); rb_define_singleton_method(kde_module, "const_missing", (VALUE (*) (...)) kde_module_method_missing, -1); - kparts_module = rb_define_module("KParts"); - rb_define_singleton_method(kparts_module, "method_missing", (VALUE (*) (...)) kde_module_method_missing, -1); - rb_define_singleton_method(kparts_module, "const_missing", (VALUE (*) (...)) kde_module_method_missing, -1); + tdeparts_module = rb_define_module("KParts"); + rb_define_singleton_method(tdeparts_module, "method_missing", (VALUE (*) (...)) kde_module_method_missing, -1); + rb_define_singleton_method(tdeparts_module, "const_missing", (VALUE (*) (...)) kde_module_method_missing, -1); kns_module = rb_define_module("KNS"); rb_define_singleton_method(kns_module, "method_missing", (VALUE (*) (...)) kde_module_method_missing, -1); @@ -2851,9 +2851,9 @@ set_new_kde(VALUE (*new_kde) (int, VALUE *, VALUE)) rb_define_singleton_method(kontact_module, "method_missing", (VALUE (*) (...)) kde_module_method_missing, -1); rb_define_singleton_method(kontact_module, "const_missing", (VALUE (*) (...)) kde_module_method_missing, -1); - ktexteditor_module = rb_define_module("KTextEditor"); - rb_define_singleton_method(ktexteditor_module, "method_missing", (VALUE (*) (...)) kde_module_method_missing, -1); - rb_define_singleton_method(ktexteditor_module, "const_missing", (VALUE (*) (...)) kde_module_method_missing, -1); + tdetexteditor_module = rb_define_module("KTextEditor"); + rb_define_singleton_method(tdetexteditor_module, "method_missing", (VALUE (*) (...)) kde_module_method_missing, -1); + rb_define_singleton_method(tdetexteditor_module, "const_missing", (VALUE (*) (...)) kde_module_method_missing, -1); twin_class = rb_define_class_under(kde_module, "Win", qt_base_class); diff --git a/smoke/kde/generate.pl.in b/smoke/kde/generate.pl.in index 3aa180da..6365c739 100644 --- a/smoke/kde/generate.pl.in +++ b/smoke/kde/generate.pl.in @@ -97,7 +97,7 @@ my %kdeexcludes = ( 'kdirnotify_stub.h' => 1, # These headers currently give problems - 'kscreensaver.h' => 1, + 'tdescreensaver.h' => 1, 'kdirnotify_stub.h' => 1, 'kio/uiserver_stub.h' => 1, 'kio/uiserver.h' => 1, @@ -106,8 +106,8 @@ my %kdeexcludes = ( 'kio/thumbcreator.h' => 1, 'kio/file.h' => 1, 'kio/chmodjob.h' => 1, - 'kparts/genericfactory.h' => 1, - 'kparts/pluginselectormodule.h' => 1, + 'tdeparts/genericfactory.h' => 1, + 'tdeparts/pluginselectormodule.h' => 1, 'kopenssl.h' => 1, 'kautomount.h' => 1, 'kimagefilepreview.h' => 1, diff --git a/smoke/kde/kde_header_list b/smoke/kde/kde_header_list index 7546ab1c..ba1c2e9f 100644 --- a/smoke/kde/kde_header_list +++ b/smoke/kde/kde_header_list @@ -168,11 +168,11 @@ kglobal.h kglobalsettings.h kguiitem.h khelpmenu.h -khtmldefaults.h -khtml_events.h -khtml_part.h -khtml_settings.h -khtmlview.h +tdehtmldefaults.h +tdehtml_events.h +tdehtml_part.h +tdehtml_settings.h +tdehtmlview.h kicondialog.h kiconeffect.h kiconloader.h @@ -204,17 +204,17 @@ kmainwindow.h kmainwindowiface.h kmanagerselection.h kmdcodec.h -kmdichildarea.h -kmdichildfrmcaption.h -kmdichildfrm.h -kmdichildview.h -kmdidefines.h -kmdiiterator.h -kmdilistiterator.h -kmdimainfrm.h -kmdinulliterator.h -kmditaskbar.h -kmditoolviewaccessor.h +tdemdichildarea.h +tdemdichildfrmcaption.h +tdemdichildfrm.h +tdemdichildview.h +tdemdidefines.h +tdemdiiterator.h +tdemdilistiterator.h +tdemdimainfrm.h +tdemdinulliterator.h +tdemditaskbar.h +tdemditoolviewaccessor.h kmenubar.h kmessagebox.h kmimemagic.h @@ -222,8 +222,8 @@ kmimesourcefactory.h kmimetype.h kmimetyperesolver.h kmountpoint.h -kmultipledrag.h -kmultitabbar.h +tdemultipledrag.h +tdemultitabbar.h knotifyclient.h knotifydialog.h knuminput.h @@ -276,8 +276,8 @@ krun.h ksavefile.h kscan.h ksconfig.h -kscreensaver.h -kscreensaver_vroot.h +tdescreensaver.h +tdescreensaver_vroot.h kselect.h kseparator.h kservicegroup.h @@ -296,8 +296,8 @@ ksockaddr.h ksock.h ksocks.h ksortablevaluelist.h -kspelldlg.h -kspell.h +tdespelldlg.h +tdespell.h ksqueezedtextlabel.h ksslall.h ksslcertchain.h @@ -332,9 +332,9 @@ kstdguiitem.h kstringhandler.h kstringvalidator.h kstyle.h -ksycocaentry.h -ksycoca.h -ksycocatype.h +tdesycocaentry.h +tdesycoca.h +tdesycocatype.h ksyntaxhighlighter.h ksystemtray.h ktabbar.h @@ -379,21 +379,21 @@ kxmlguiclient.h kxmlguifactory.h kxmlgui.h kzip.h -kparts/browserextension.h -kparts/browserinterface.h -kparts/browserrun.h -kparts/componentfactory.h -kparts/dockmainwindow.h -kparts/event.h -kparts/factory.h -kparts/genericfactory.h -kparts/historyprovider.h -kparts/mainwindow.h -kparts/part.h -kparts/partmanager.h -kparts/plugin.h -kparts/pluginselectormodule.h -kparts/statusbarextension.h +tdeparts/browserextension.h +tdeparts/browserinterface.h +tdeparts/browserrun.h +tdeparts/componentfactory.h +tdeparts/dockmainwindow.h +tdeparts/event.h +tdeparts/factory.h +tdeparts/genericfactory.h +tdeparts/historyprovider.h +tdeparts/mainwindow.h +tdeparts/part.h +tdeparts/partmanager.h +tdeparts/plugin.h +tdeparts/pluginselectormodule.h +tdeparts/statusbarextension.h kio/authinfo.h kio/chmodjob.h kio/connection.h diff --git a/xparts/doc/kparts.fig b/xparts/doc/tdeparts.fig similarity index 100% rename from xparts/doc/kparts.fig rename to xparts/doc/tdeparts.fig diff --git a/xparts/doc/kparts.png b/xparts/doc/tdeparts.png similarity index 100% rename from xparts/doc/kparts.png rename to xparts/doc/tdeparts.png diff --git a/xparts/doc/xparts.html b/xparts/doc/xparts.html index ad51c5a1..627c85f7 100644 --- a/xparts/doc/xparts.html +++ b/xparts/doc/xparts.html @@ -26,7 +26,7 @@

    In order to understand, what is extending about XParts, first a brief overview on how KParts work. - +

    Imagine an application - for example the integrated file manager "Konqueror" - wants to utilize a component that handles the diff --git a/xparts/mozilla/Makefile.am b/xparts/mozilla/Makefile.am index ad5ed675..743ce97e 100644 --- a/xparts/mozilla/Makefile.am +++ b/xparts/mozilla/Makefile.am @@ -18,7 +18,7 @@ kmozilla_LDADD = ../src/gtk/libgtkxparts.la $(GTK2_LIBS) $(GLIB2_LIBS) kmozilla_LDFLAGS = $(MOZILLA_LDFLAGS) $(GLIB2_LDFLAGS) $(GTK2_LIBS) -L/usr/lib/mozilla -Wl,--rpath=/usr/lib/mozilla -lxul -lxpcom -lmozjs $(all_libraries) #kshell_SOURCES = kshell.cpp -#kshell_LDADD = $(top_builddir)/xkparts/kde/libkdexparts.la +#kshell_LDADD = $(top_builddir)/xtdeparts/kde/libkdexparts.la #kshell_LDFLAGS = $(all_libraries) METASOURCES = AUTO diff --git a/xparts/mozilla/kmozilla.rc b/xparts/mozilla/kmozilla.rc index 9c80e6c3..e0441a85 100644 --- a/xparts/mozilla/kmozilla.rc +++ b/xparts/mozilla/kmozilla.rc @@ -1,5 +1,5 @@ - +

    diff --git a/xparts/mozilla/kmozillapart.cpp b/xparts/mozilla/kmozillapart.cpp index f083d779..625de5ad 100644 --- a/xparts/mozilla/kmozillapart.cpp +++ b/xparts/mozilla/kmozillapart.cpp @@ -7,10 +7,10 @@ #include #include #include -#include +#include #include #include -#include +#include typedef KParts::GenericFactory KMozillaPartFactory; K_EXPORT_COMPONENT_FACTORY( libkmozillapart, KMozillaPartFactory ); diff --git a/xparts/mozilla/kshell.cpp b/xparts/mozilla/kshell.cpp index 9e83f9a4..b6935b47 100644 --- a/xparts/mozilla/kshell.cpp +++ b/xparts/mozilla/kshell.cpp @@ -8,7 +8,7 @@ #include #include #include -#include +#include #include class ShellWindow : public KParts::MainWindow @@ -62,7 +62,7 @@ private: int main( int argc, char **argv ) { - TDEApplication app( argc, argv, "xkpartsshell" ); + TDEApplication app( argc, argv, "xtdepartsshell" ); app.dcopClient()->registerAs("kshell"); diff --git a/xparts/src/gtk/Makefile.am b/xparts/src/gtk/Makefile.am index 60a7a194..839e43db 100644 --- a/xparts/src/gtk/Makefile.am +++ b/xparts/src/gtk/Makefile.am @@ -10,4 +10,4 @@ libgtkxparts_la_LIBADD = $(GTK2_LIBS) $(GLIB2_LIBS) $(top_builddir)/dcopc/libdco libgtkxparts_la_LDFLAGS = -L$(prefix)/lib $(all_libraries) -no-undefined gtkxpartsinclude_HEADERS = gtkpart.h gtkbrowserextension.h -gtkxpartsincludedir = $(includedir)/xkparts +gtkxpartsincludedir = $(includedir)/xtdeparts diff --git a/xparts/src/interfaces/Makefile.am b/xparts/src/interfaces/Makefile.am index 0d4b7f97..21b08ed6 100644 --- a/xparts/src/interfaces/Makefile.am +++ b/xparts/src/interfaces/Makefile.am @@ -1,3 +1,3 @@ -xkpartsinclude_HEADERS = xpart.h xparthost.h -xkpartsincludedir = $(includedir)/xkparts +xtdepartsinclude_HEADERS = xpart.h xparthost.h +xtdepartsincludedir = $(includedir)/xtdeparts diff --git a/xparts/src/interfaces/xpart.h b/xparts/src/interfaces/xpart.h index 5c44cbbd..819e65d2 100644 --- a/xparts/src/interfaces/xpart.h +++ b/xparts/src/interfaces/xpart.h @@ -1,5 +1,5 @@ -#ifndef __xkparts_part_h__ -#define __xkparts_part_h__ +#ifndef __xtdeparts_part_h__ +#define __xtdeparts_part_h__ #include #include diff --git a/xparts/src/interfaces/xparthost.h b/xparts/src/interfaces/xparthost.h index 75c6f4e0..40958086 100644 --- a/xparts/src/interfaces/xparthost.h +++ b/xparts/src/interfaces/xparthost.h @@ -1,5 +1,5 @@ -#ifndef __xkparts_parthost_h__ -#define __xkparts_parthost_h__ +#ifndef __xtdeparts_parthost_h__ +#define __xtdeparts_parthost_h__ #include #include diff --git a/xparts/src/interfaces/xpartmanager.h b/xparts/src/interfaces/xpartmanager.h index 25a341f8..714b0984 100644 --- a/xparts/src/interfaces/xpartmanager.h +++ b/xparts/src/interfaces/xpartmanager.h @@ -1,5 +1,5 @@ -#ifndef __xkparts_partmanager_h__ -#define __xkparts_partmanager_h__ +#ifndef __xtdeparts_partmanager_h__ +#define __xtdeparts_partmanager_h__ #include #include diff --git a/xparts/src/kde/kbrowsersignals.h b/xparts/src/kde/kbrowsersignals.h index 3bd29a7f..baee95aa 100644 --- a/xparts/src/kde/kbrowsersignals.h +++ b/xparts/src/kde/kbrowsersignals.h @@ -2,7 +2,7 @@ #define __kbrowsersignals_h__ #include -#include +#include #include class XBrowserExtension_stub; diff --git a/xparts/src/kde/xparthost_kpart.h b/xparts/src/kde/xparthost_kpart.h index 527178d2..829f7ca7 100644 --- a/xparts/src/kde/xparthost_kpart.h +++ b/xparts/src/kde/xparthost_kpart.h @@ -3,7 +3,7 @@ #include -#include +#include class XPart_stub; class KBrowserSignals; diff --git a/xparts/xpart_notepad/shell_xparthost.cpp b/xparts/xpart_notepad/shell_xparthost.cpp index 8bb4ce65..8ea38f75 100644 --- a/xparts/xpart_notepad/shell_xparthost.cpp +++ b/xparts/xpart_notepad/shell_xparthost.cpp @@ -9,7 +9,7 @@ #include #include #include -#include +#include #include ShellWindow::ShellWindow() diff --git a/xparts/xpart_notepad/shell_xparthost.h b/xparts/xpart_notepad/shell_xparthost.h index 7a0bb1a8..590a6293 100644 --- a/xparts/xpart_notepad/shell_xparthost.h +++ b/xparts/xpart_notepad/shell_xparthost.h @@ -2,7 +2,7 @@ #define shell_xparthost_h #include -#include +#include #include class TDEProcess; diff --git a/xparts/xpart_notepad/xp_notepad_factory.cpp b/xparts/xpart_notepad/xp_notepad_factory.cpp index 7d9b4d12..f815fd4d 100644 --- a/xparts/xpart_notepad/xp_notepad_factory.cpp +++ b/xparts/xpart_notepad/xp_notepad_factory.cpp @@ -25,7 +25,7 @@ #include #include #include -#include +#include #include #include "xp_notepad_factory.h" diff --git a/xparts/xpart_notepad/xp_notepad_factory.h b/xparts/xpart_notepad/xp_notepad_factory.h index cb3090c6..83c5274f 100644 --- a/xparts/xpart_notepad/xp_notepad_factory.h +++ b/xparts/xpart_notepad/xp_notepad_factory.h @@ -21,7 +21,7 @@ #ifndef __xp_notepad_factory_h__ #define __xp_notepad_factory_h__ -#include +#include #include #include #include "xparthost_kpart.h"
diff --git a/kdejava/koala/org/kde/koala/KHTMLPart.java b/kdejava/koala/org/kde/koala/KHTMLPart.java
index 56f5b35f..13abfc0f 100644
--- a/kdejava/koala/org/kde/koala/KHTMLPart.java
+++ b/kdejava/koala/org/kde/koala/KHTMLPart.java
@@ -17,7 +17,7 @@ import org.kde.qt.TQWidget;
 
 /**
 
- This class is khtml's main class. It features an almost complete
+ This class is tdehtml's main class. It features an almost complete
  web browser, and html renderer.
  The easiest way to use this class (if you just want to display an HTML
  page at some URL) is the following:
@@ -216,7 +216,7 @@ public class KHTMLPart extends ReadOnlyPart  {
 		   		@short    Returns a pointer to the KParts.BrowserExtension.
 	*/
 	public native BrowserExtension browserExtension();
 	// KParts::LiveConnectExtension* liveConnectExtension(const khtml::RenderPart* arg1); >>>> NOT CONVERTED
 	public native BrowserHostExtension browserHostExtension();
 	/**	
 		 Returns a pointer to the HTML document's view.
@@ -734,7 +734,7 @@ public class KHTMLPart extends ReadOnlyPart  {
 		 frame info in childFrame
 				@short    Recursively finds the part containing the frame with name f  and checks if it is accessible by callingPart  Returns 0L if no suitable frame can't be found.
 	*/
-	// KHTMLPart* findFrameParent(KParts::ReadOnlyPart* arg1,const TQString& arg2,khtml::ChildFrame** arg3); >>>> NOT CONVERTED
+	// KHTMLPart* findFrameParent(KParts::ReadOnlyPart* arg1,const TQString& arg2,tdehtml::ChildFrame** arg3); >>>> NOT CONVERTED
 	public native KHTMLPart findFrameParent(ReadOnlyPart callingPart, String f);
 	/**	
 		 Return the current frame (the one that has focus)
@@ -931,30 +931,30 @@ public class KHTMLPart extends ReadOnlyPart  {
 	protected native void htmlError(int errorCode, String text, KURL reqUrl);
 	protected native void customEvent(TQCustomEvent event);
 	/**	
-		 Eventhandler of the khtml.MousePressEvent.
-		   		@short    Eventhandler of the khtml.MousePressEvent.
+		 Eventhandler of the tdehtml.MousePressEvent.
+		   		@short    Eventhandler of the tdehtml.MousePressEvent.
 	*/
 	// void khtmlMousePressEvent(khtml::MousePressEvent* arg1); >>>> NOT CONVERTED
 	/**	
-		 Eventhandler for the khtml.MouseDoubleClickEvent.
-		   		@short    Eventhandler for the khtml.MouseDoubleClickEvent.
+		 Eventhandler for the tdehtml.MouseDoubleClickEvent.
+		   		@short    Eventhandler for the tdehtml.MouseDoubleClickEvent.
 	*/
 	// void khtmlMouseDoubleClickEvent(khtml::MouseDoubleClickEvent* arg1); >>>> NOT CONVERTED
 	/**	
-		 Eventhandler for the khtml.MouseMouseMoveEvent.
-		   		@short    Eventhandler for the khtml.MouseMouseMoveEvent.
+		 Eventhandler for the tdehtml.MouseMouseMoveEvent.
+		   		@short    Eventhandler for the tdehtml.MouseMouseMoveEvent.
 	*/
 	// void khtmlMouseMoveEvent(khtml::MouseMoveEvent* arg1); >>>> NOT CONVERTED
 	/**	
-		 Eventhandler for the khtml.MouseMouseReleaseEvent.
-		   		@short    Eventhandler for the khtml.MouseMouseReleaseEvent.
+		 Eventhandler for the tdehtml.MouseMouseReleaseEvent.
+		   		@short    Eventhandler for the tdehtml.MouseMouseReleaseEvent.
 	*/
 	// void khtmlMouseReleaseEvent(khtml::MouseReleaseEvent* arg1); >>>> NOT CONVERTED
 	/**	
-		 Eventhandler for the khtml.DrawContentsEvent.
-		   		@short    Eventhandler for the khtml.DrawContentsEvent.
+		 Eventhandler for the tdehtml.DrawContentsEvent.
+		   		@short    Eventhandler for the tdehtml.DrawContentsEvent.
 	*/
 	// void khtmlDrawContentsEvent(khtml::DrawContentsEvent* arg1); >>>> NOT CONVERTED
 	/**	
 		 Internal reimplementation of KParts.Part.guiActivateEvent .
 		   		@short    Internal reimplementation of KParts.Part.guiActivateEvent .
@@ -216,7 +216,7 @@ public class KHTMLPart extends ReadOnlyPart  {
 	*/
 	public native BrowserExtension browserExtension();
-	// KParts::LiveConnectExtension* liveConnectExtension(const khtml::RenderPart* arg1); >>>> NOT CONVERTED
+	// KParts::LiveConnectExtension* liveConnectExtension(const tdehtml::RenderPart* arg1); >>>> NOT CONVERTED
 	public native BrowserHostExtension browserHostExtension();
 	/**	
@@ -931,30 +931,30 @@ public class KHTMLPart extends ReadOnlyPart  {
 	*/
-	// void khtmlMousePressEvent(khtml::MousePressEvent* arg1); >>>> NOT CONVERTED
+	// void tdehtmlMousePressEvent(tdehtml::MousePressEvent* arg1); >>>> NOT CONVERTED
 	/**	
@@ -931,30 +931,30 @@ public class KHTMLPart extends ReadOnlyPart  {
 	*/
-	// void khtmlMouseDoubleClickEvent(khtml::MouseDoubleClickEvent* arg1); >>>> NOT CONVERTED
+	// void tdehtmlMouseDoubleClickEvent(tdehtml::MouseDoubleClickEvent* arg1); >>>> NOT CONVERTED
 	/**	
@@ -931,30 +931,30 @@ public class KHTMLPart extends ReadOnlyPart  {
 	*/
-	// void khtmlMouseMoveEvent(khtml::MouseMoveEvent* arg1); >>>> NOT CONVERTED
+	// void tdehtmlMouseMoveEvent(tdehtml::MouseMoveEvent* arg1); >>>> NOT CONVERTED
 	/**	
@@ -931,30 +931,30 @@ public class KHTMLPart extends ReadOnlyPart  {
 	*/
-	// void khtmlMouseReleaseEvent(khtml::MouseReleaseEvent* arg1); >>>> NOT CONVERTED
+	// void tdehtmlMouseReleaseEvent(tdehtml::MouseReleaseEvent* arg1); >>>> NOT CONVERTED
 	/**	
@@ -931,30 +931,30 @@ public class KHTMLPart extends ReadOnlyPart  {
 	*/
-	// void khtmlDrawContentsEvent(khtml::DrawContentsEvent* arg1); >>>> NOT CONVERTED
+	// void tdehtmlDrawContentsEvent(tdehtml::DrawContentsEvent* arg1); >>>> NOT CONVERTED
 	/**	
 		 Internal reimplementation of KParts.Part.guiActivateEvent .